# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import UI4.FormMaster.ParameterCurveEditSet as ParameterCurveEditSet
import PyFCurve as PyFCurve
import PyQt5.QtCore
import PyXmlIO as PyXmlIO
import PyQt5.QtCore as QtCore
import UI4.FormMaster.States as States
import Utils as Utils
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from typing import Set, Tuple

class CurveParameterPolicy(BaseParameterPolicy):
    def __init__(self, param, parent) -> None: ...
    def _CurveParameterPolicy__isValidFCurveElementInMimeData(self, mimeData): ...
    def canHaveCurve(self): ...
    def checkMimeData(self, mimeData): ...
    def getCurveAutoKey(self): ...
    def getCurveKey(self): ...
    def getMimeData(self) -> PyQt5.QtCore.QMimeData: ...
    def getValue(self): ...
    def getValueState(self): ...
    def isCurveEnabled(self): ...
    def isCurveViewed(self): ...
    def setCurveAutoKey(self, autoKey): ...
    def setCurveEnabled(self, state): ...
    def setCurveKey(self, state): ...
    def setCurveViewed(self, state): ...
    def setMimeData(self, mimeData, dropAction): ...
    def setValue(self, value, final: bool = ...): ...
    def setValueState(self, state): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.BypassParameterManager as BypassParameterManager
import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from PyUtilModule.VirtualKatana import RenderManager as RenderManager
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from UI4.Tabs.NodeGraphTab.Layers.BandSelectionLayer import BandSelectionLayer as BandSelectionLayer
from UI4.Tabs.NodeGraphTab.Layers.BookmarkJumpMenuLayer import BookmarkJumpMenuLayer as BookmarkJumpMenuLayer
from UI4.Tabs.NodeGraphTab.Layers.CustomMenuLayer import CustomMenuLayer as CustomMenuLayer
from UI4.Tabs.NodeGraphTab.Layers.LinkConnectionLayer import LinkConnectionLayer as LinkConnectionLayer
from UI4.Tabs.NodeGraphTab.Layers.NodeCreationMenuLayer import NodeCreationMenuLayer as NodeCreationMenuLayer
from UI4.Widgets.NodePopupMenu import NodePopupMenu as NodePopupMenu
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

EDIT_VIEW_NODETYPE_EXCLUSIONS: list
RENAME_NODETYPE_EXCLUSIONS: list

class NodeInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    _NodeInteractionLayer__pixmaps: ClassVar[dict] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def _NodeInteractionLayer__buildNodeMenu(self, node: NodegraphAPI.Node, port: NodegraphAPI.Port, *args): ...
    def _NodeInteractionLayer__createDotNode(self) -> bool: ...
    def _NodeInteractionLayer__deleteNodes(self, nodeList): ...
    def _NodeInteractionLayer__getFocusedGroupNode(self): ...
    def _NodeInteractionLayer__isDisplayedAsDot(self, node: NodegraphAPI.Node) -> bool: ...
    def _NodeInteractionLayer__launchNodeCreationMenuLayer(self, replacedNode: Incomplete | None = ...): ...
    def _NodeInteractionLayer__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _NodeInteractionLayer__nodePickerLayerFinished(self, createdNodes, replacedNode: Incomplete | None = ...): ...
    def _NodeInteractionLayer__populateEntries(self): ...
    def _NodeInteractionLayer__processKeyPress(self, event): ...
    def _NodeInteractionLayer__processMouseButtonDblClick(self, event): ...
    def _NodeInteractionLayer__processMouseButtonPress(self, event): ...
    def _NodeInteractionLayer__processMouseButtonRelease(self, event): ...
    def _NodeInteractionLayer__processMouseMove(self, event): ...
    def _NodeInteractionLayer__renameNode(self, node: NodegraphAPI.Node) -> bool: ...
    def _NodeInteractionLayer__startNodeDrag(self, node: NodegraphAPI.Node): ...
    def _createBreakoutNode(self): ...
    def _on_nodegraph_registerType(self, eventType: str | None, eventID: object, type: str): ...
    def frameSelection(self, zoom: bool = ...): ...
    def processEvent(self, event): ...
    def showJumpToBookmark(self): ...
    def showLayeredMenu(self, menu): ...
    def startDrag(self): ...

def _GetTopMostBackdropNodeFromHitList(hitList): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Set, Tuple

def RemoveTimeSamplesIfAllSame(arg0: PyFnAttribute.Attribute) -> PyFnAttribute.Attribute: ...
def RemoveTimeSamplesUnneededForShutter(arg0: PyFnAttribute.Attribute, arg1: float, arg2: float) -> PyFnAttribute.Attribute: ...
def ResampleAttrWithInterp(arg0: PyFnAttribute.Attribute, arg1: PyFnAttribute.DataAttribute) -> PyFnAttribute.Attribute: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyFnAttribute
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import RenderingAPI as RenderingAPI
import UI4.Widgets.SceneGraphView.SceneGraphLocationTranslation as SceneGraphLocationTranslation
import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import UI4.FormMaster.Editors.ScenegraphColumnDescription as ScenegraphColumnDescription
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import Nodes3DAPI.ScenegraphMask as ScenegraphMask
import UI4 as UI4
import Utils as Utils
import typing
from PyUtilModule.VirtualKatana import NodeDebugOutput as NodeDebugOutput, Shelves as Shelves
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs, Prefs as Prefs
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from UI4.Tabs.SceneGraphTab.LightListPopup import LightListPopup as LightListPopup
from UI4.Tabs.SceneGraphTab.SceneGraphBookmarkButton import SceneGraphBookmarkButton as SceneGraphBookmarkButton
from UI4.Tabs.SceneGraphTab.SceneGraphTabColumn import SceneGraphTabColumnSet as SceneGraphTabColumnSet
from UI4.Tabs.SceneGraphTab.SceneGraphTabItems import AltErrorMessageItem as AltErrorMessageItem, CollectionsRootItem as CollectionsRootItem, ErrorMessageItem as ErrorMessageItem, WarningMessageItem as WarningMessageItem
from UI4.Tabs.SceneGraphTab.SceneGraphTabNameItemDelegate import SceneGraphTabNameItemDelegate as SceneGraphTabNameItemDelegate
from UI4.Util.AttributeHistory import AttributeHistory as AttributeHistory
from UI4.Widgets.SceneGraphView.ColumnDataType import ColumnDataType as ColumnDataType
from UI4.Widgets.SceneGraphView.SceneGraphFindButton import SceneGraphFindButton as SceneGraphFindButton
from UI4.Widgets.SceneGraphView.SceneGraphView import SceneGraphView
from UI4.Widgets.SceneGraphView.SceneGraphViewColumn import SceneGraphColumnTitle as SceneGraphColumnTitle
from UI4.Widgets.ShelfButton import ShelfButton
from typing import ClassVar, Set, Tuple

class SceneGraphTab(BaseTab):
    _SceneGraphTab__columnPrefKeys: ClassVar[tuple] = ...
    _SceneGraphTab__customColumnsSetName: ClassVar[str] = ...
    _SceneGraphTab__defaultTypeColumnWidth: ClassVar[int] = ...
    _SceneGraphTab__instanceSourceAttrName: ClassVar[str] = ...
    _SceneGraphTab__lightListAttributeName: ClassVar[str] = ...
    _SceneGraphTab__materialAssignAttrName: ClassVar[str] = ...
    _SceneGraphTab__maxEventsPerIdle: ClassVar[int] = ...
    _SceneGraphTab__polishOpType: ClassVar[str] = ...
    groupWidgetClosed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None, flags: int = ...) -> None: ...
    def _SceneGraphTab__attributeHistoryCallback(self, nodeHistory): ...
    def _SceneGraphTab__buildLayout(self): ...
    def _SceneGraphTab__clearPinsBelow(self): ...
    def _SceneGraphTab__clearPinsBelowActionCallback(self): ...
    def _SceneGraphTab__collectAndSelectActionCallback(self): ...
    def _SceneGraphTab__configureSceneGraphView(self): ...
    def _SceneGraphTab__contextMenuEventCallback(self, contextMenuEvent, menu): ...
    def _SceneGraphTab__copyPaths(self): ...
    def _SceneGraphTab__copySelectionActionCallback(self): ...
    def _SceneGraphTab__errorStateChangedCallback(self, errorMessageItemRefs): ...
    def _SceneGraphTab__expandToLocation(self, locationPath: str): ...
    def _SceneGraphTab__findSceneGraphLocationActionCallback(self): ...
    def _SceneGraphTab__focusActionCallback(self): ...
    def _SceneGraphTab__freeze(self): ...
    def _SceneGraphTab__getAssignedMaterials(self, locations) -> set[str]: ...
    def _SceneGraphTab__getAttribute(self, locationPath: str, attributeName: str) -> PyFnAttribute | None: ...
    def _SceneGraphTab__getAttributeValuesAsAbsolutePaths(self, locations, attributeName: str) -> set[str]: ...
    def _SceneGraphTab__getColumnIcon(self, baseName: str) -> PyQt5.QtGui.QIcon: ...
    def _SceneGraphTab__getDescendantsRecursive(self, location, leavesOnly, visibleOnly, result): ...
    def _SceneGraphTab__getInstanceSources(self, locations) -> set[str]: ...
    def _SceneGraphTab__getPinnedLocations(self, selectedOnly: bool = ...): ...
    def _SceneGraphTab__lightsColumnTitleClickedCallback(self, columnTitleRect): ...
    def _SceneGraphTab__locationCollapsedCallback(self, locationPath, topLevelLocationPath, recursive): ...
    def _SceneGraphTab__locationExpandedCallback(self, locationPath, topLevelLocationPath, recursive): ...
    def _SceneGraphTab__navigationToolbarCallback(self, nodeName: str, isBack: bool): ...
    def _SceneGraphTab__onPrefChanged(self, eventType: str | None, eventID: typing.Hashable, prefKey: str, prefValue: object): ...
    def _SceneGraphTab__on_event_idle(self): ...
    def _SceneGraphTab__on_node_setName(self, eventType: str | None, eventID: object, node: Nodes3DAPI.Node3D | Nodes2DAPI.Node2D, oldName: str, newName: str): ...
    def _SceneGraphTab__on_node_setViewed(self, args): ...
    def _SceneGraphTab__on_nodegraph_setCurrentTime(self, eventType: str | None, eventID: object, currentTime: float): ...
    def _SceneGraphTab__on_pref_changed(self, args): ...
    def _SceneGraphTab__on_scenegraphManager_implicitResolversActive(self, eventType, scenegraphID, implicitResolversActive, **kwargs): ...
    def _SceneGraphTab__on_scenegraphManager_locationClosed(self, eventType, eventID, location, sender): ...
    def _SceneGraphTab__on_scenegraphManager_locationOpened(self, eventType, eventID, location, sender): ...
    def _SceneGraphTab__on_scenegraphManager_locationOpenedRecursively(self, eventType, eventID, location, sender): ...
    def _SceneGraphTab__on_scenegraphManager_pinChanged(self, eventType, eventID, locations, sender): ...
    def _SceneGraphTab__on_scenegraphManager_selectionChanged(self, eventType: str | None, eventID: object, selectedLocations, deselectedLocations, sender: object | None): ...
    def _SceneGraphTab__on_scenegraphMask_visibilityFollowsWorkingSetChanged(self, eventType, eventID, visibilityFollowsWorkingSet): ...
    def _SceneGraphTab__on_scenegraph_interruptProcessing(self, eventType, eventID): ...
    def _SceneGraphTab__on_viewer_visibilityFollowsWorkingSetChanged(self, eventType, eventID, visibilityFollowsWorkingSet): ...
    def _SceneGraphTab__pinVisibleLeavesActionCallback(self): ...
    def _SceneGraphTab__printRenderOutput(self, methodName: str, rendererName: str, openInEditor: bool = ..., printToConsole: bool = ...): ...
    def _SceneGraphTab__refreshCustomColumnsFromPrefs(self): ...
    def _SceneGraphTab__refreshOpArgs(self): ...
    def _SceneGraphTab__removeLocalPinsActionCallback(self): ...
    def _SceneGraphTab__renderColumnTitleClickedCallback(self, columnTitleRect): ...
    def _SceneGraphTab__renderWorkingSetStatusChanged(self, isActive): ...
    def _SceneGraphTab__sceneGraphAttributesCallback(self, locationPath: str, attributes: PyFnAttribute.GroupAttribute | None) -> bool: ...
    def _SceneGraphTab__selectAssignedMaterials(self, replaceSelection: bool = ...): ...
    def _SceneGraphTab__selectAssignedMaterialsActionCallback(self): ...
    def _SceneGraphTab__selectChildren(self, replaceSelection: bool = ...): ...
    def _SceneGraphTab__selectChildrenActionCallback(self): ...
    def _SceneGraphTab__selectInstanceSources(self, replaceSelection: bool = ...): ...
    def _SceneGraphTab__selectInstanceSourcesActionCallback(self): ...
    def _SceneGraphTab__selectParents(self, replaceSelection: bool = ...): ...
    def _SceneGraphTab__selectParentsActionCallback(self): ...
    def _SceneGraphTab__selectionChangedCallback(self): ...
    def _SceneGraphTab__selectionHasInstanceSource(self) -> bool: ...
    def _SceneGraphTab__selectionHasMaterialAssigned(self) -> bool: ...
    def _SceneGraphTab__setDescendantsPinned(self, pinned: bool = ..., leavesOnly: bool = ..., visibleOnly: bool = ...): ...
    def _SceneGraphTab__setLocalPinsActionCallback(self): ...
    def _SceneGraphTab__setSelectionPinned(self, pinned: bool = ...): ...
    def _SceneGraphTab__setVisibilityFollowsWorkingSet(self, visibilityFollowsWorkingSet): ...
    def _SceneGraphTab__thaw(self): ...
    def _SceneGraphTab__updateLayout(self, oldSize: PyQt5.QtGui.QSize, size: PyQt5.QtGui.QSize): ...
    def _SceneGraphTab__updateNodeErrors(self): ...
    def _SceneGraphTab__updateViewNode(self, updateIf2D: bool = ..., updateIfNone: bool = ...): ...
    def _SceneGraphTab__validateDrag(self, event): ...
    def _SceneGraphTab__viewerVisibilityColumnTitleClickedCallback(self, columnTitleRect): ...
    def _SceneGraphTab__visibilityWorkingSetStatusChanged(self, isActive): ...
    def applySettings(self, settings: dict): ...
    def dragEnterEvent(self, event): ...
    def dragMoveEvent(self, event): ...
    def dropEvent(self, event): ...
    def getSceneGraphView(self) -> SceneGraphView: ...
    def getSettings(self) -> dict: ...
    def hideEvent(self, event: PyQt5.QtGui.QHideEvent): ...
    def on_lightListPopup_changed(self, selectedLights): ...
    def on_stopButton_pressed(self): ...
    def on_viewNodeButton_clicked(self): ...
    @staticmethod
    def registerKeyboardShortcuts(): ...
    def resizeEvent(self, event: PyQt5.QtGui.QResizeEvent): ...
    def scrollToLocations(self, locationPaths: list[str]): ...
    def showEvent(self, event: PyQt5.QtGui.QShowEvent): ...

class SceneGraphTabShelfButton(ShelfButton):
    ShelfSuffix: ClassVar[str] = ...
    def __init__(self, parent) -> None: ...
    @staticmethod
    def ShelfQuery(forceReload: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class PanelScrollArea(PyQt5.QtWidgets.QScrollArea):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyUtilModule.KatanaFile as KatanaFile
import NodegraphAPI as NodegraphAPI
import Utils as Utils
import PyXmlIO as XmlIO
import typing
import xml.etree.ElementTree
from . import FarmManager as FarmManager, FarmPluginManager as FarmPluginManager
from PyUtilModule.FarmAPI.BaseFarmPlugin import BaseFarmPlugin as BaseFarmPlugin, FarmPluginException as FarmPluginException, Job as Job, JobNotFoundException as JobNotFoundException
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

NODES_ALL: str
NODES_SELECTED: str
NODES_SINGLE: str

class FarmSetting:
    NUMBER: ClassVar[str] = ...
    NUMBERARRAY: ClassVar[str] = ...
    QUALIFIER: ClassVar[str] = ...
    STRING: ClassVar[str] = ...
    STRINGARRAY: ClassVar[str] = ...
    VALID_TYPES: ClassVar[tuple] = ...
    def __init__(self, name: str = ..., farmType: str = ..., defaultValue: Incomplete | None = ..., size: int = ..., hints: Incomplete | None = ...) -> None: ...
    def getHints(self) -> dict | None: ...
    def getName(self) -> str: ...
    def getQualifiedName(self) -> str: ...
    def getShortName(self): ...
    def getSize(self) -> int: ...
    def getType(self) -> str: ...
    def getValue(self) -> str | int | float | list | None: ...

class NodeRenderSettings:
    def __init__(self, dependencyListEntry: Incomplete | None = ...) -> None: ...
    def _NodeRenderSettings__initialize(self): ...
    def _NodeRenderSettings__setFromDependencyListEntry(self, dependencyListEntry: dict | None): ...
    def getNode(self) -> NodegraphAPI.Node | None: ...
    def getNodeType(self) -> str: ...

class RenderScriptSettings:
    def __init__(self, settings: dict = ...) -> None: ...
    def appendXML(self, xmlElement: xml.etree.ElementTree.Element): ...

def AddErrorMessage(message: str): ...
def AddFarmMenuOption(menuCommandText: str, callback: typing.Callable): ...
def AddFarmPopupMenuOption(menuCommandText: str, callback: typing.Callable): ...
def AddFarmSettingNumber(name: str = ..., defaultValue: int = ..., hints: Incomplete | None = ...): ...
def AddFarmSettingNumberArray(name: str = ..., size: int = ..., hints: Incomplete | None = ...): ...
def AddFarmSettingString(name: str = ..., defaultValue: str = ..., hints: Incomplete | None = ...): ...
def AddFarmSettingStringArray(name: str = ..., size: int = ..., hints: Incomplete | None = ...): ...
def AddWarningMessage(message: str): ...
def ExtractFarmSettingsFromNode(node: NodegraphAPI.Node) -> dict: ...
def GetAddedFarmSettings() -> list[FarmSetting]: ...
def GetClickedNode() -> NodegraphAPI.Node: ...
def GetCurrentNode() -> NodegraphAPI.Node: ...
def GetCurrentNodeFrameRange() -> dict: ...
def GetErrorMessages() -> list[str]: ...
def GetFarmMenuOptions() -> list[None]: ...
def GetFarmPopupMenuOptions() -> list[None]: ...
def GetKatanaFileName() -> str: ...
def GetNodeList() -> list[NodegraphAPI.Node | None]: ...
def GetNodeProcessType() -> str: ...
def GetSceneFrameRange() -> dict: ...
def GetSelectedNodes() -> list[NodegraphAPI.Node]: ...
def GetSortedDependencies(nodeOrNodes: Incomplete | None = ..., includeBypassed: bool = ...) -> list[NodeRenderSettings]: ...
def GetSortedDependencyList(nodeList: Incomplete | None = ..., syncAllOutputPorts: bool = ..., includeInternalDeps: bool = ...): ...
def GetWarningMessages() -> list[str]: ...
def Initialise(clickedNode: Incomplete | None = ...): ...
def IsSceneValid(nodeScope: Incomplete | None = ..., allowUnsavedChanges: bool = ..., allowCapitalLetters: bool = ..., allowDigits: bool = ..., unwantedSymbols: list = ...) -> bool: ...
def OpenDefaultDialog(callback: Incomplete | None = ..., dialogTitle: str = ..., fileExtension: str = ...): ...
def WriteFarmFile(fileName, farmString): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import UI4.Util.IconManager as IconManager
import NodeGraphTab
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import Nodes3DAPI.ShadingNodeBase as ShadingNodeBase
import Utils as Utils
from UI4.Util.ScenegraphLocation import GetNodesCreatingSceneGraphLocations as GetNodesCreatingSceneGraphLocations
from typing import Set, Tuple

MIME_TYPE_NODEREFS: str
MIME_TYPE_NODES: str

def CheckNodeMimeData(mimeData, requireExtant: bool = ...): ...
def GetNodeMimeData(nodeList): ...
def GetNodesFromMimeData(mimeData: PyQt5.QtCore.QMimeData, raiseIfMissingData: bool = ...) -> list: ...
def StartNodeDrag(nodeList, dragSource): ...
def StartPortDrag(port: NodegraphAPI.Port, dragSource: NodeGraphTab.NodegraphWidget): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyResolutionTableFn as ResolutionTable
from typing import Set, Tuple

def GetTempResolutionTablePath() -> str: ...
def SaveResolutionTables(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class ResourceManager:
    def __init__(self, paths, exceptionForMissing: bool = ...) -> None: ...
    def clearCache(self): ...
    def getResourceFile(self, resourceName): ...
    def isExceptionForMissing(self): ...
    def setExceptionForMissing(self, doExc): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Any, ClassVar, Set, Tuple, overload

CHANGE_TYPE_BEGIN: FCurve.ChangeType
CHANGE_TYPE_END: FCurve.ChangeType
CHANGE_TYPE_INTERMEDIATE: FCurve.ChangeType
CHANGE_TYPE_NORMAL: FCurve.ChangeType
CLAMPED_TANGENT: Tangent.TangentType
CURVE_ASSIGNED: FCurveObserver.CurveIntrinsicType
CURVE_CLEARED: FCurveObserver.CurveIntrinsicType
CURVE_NAME_CHANGED: FCurveObserver.CurveIntrinsicType
CURVE_SWAPPED: FCurveObserver.CurveIntrinsicType
FIXED_TANGENT: Tangent.TangentType
FLAT_TANGENT: Tangent.TangentType
KEYFRAME_BREAKDOWN_CHANGED: FCurveObserver.KeyframeIntrinsicType
KEYFRAME_POSITION_CHANGED: FCurveObserver.KeyframeIntrinsicType
KEYFRAME_UNIFIED_CHANGED: FCurveObserver.KeyframeIntrinsicType
LINEAR_TANGENT: Tangent.TangentType
PLATEAU_TANGENT: Tangent.TangentType
SEGMENT_INTERPOLATOR_CHANGED: FCurveObserver.SegmentIntrinsicType
SMOOTH_NORMAL_TANGENT: Tangent.TangentType
SMOOTH_TANGENT: Tangent.TangentType
TANGENT_LOCKED_WEIGHT_CHANGED: FCurveObserver.TangentIntrinsicType
TANGENT_TYPE_CHANGED: FCurveObserver.TangentIntrinsicType
TANGENT_VECTOR_CHANGED: FCurveObserver.TangentIntrinsicType
TANGENT_WEIGHTED_CHANGED: FCurveObserver.TangentIntrinsicType

class ContainerObserver:
    def __init__(self) -> None: ...
    @overload
    def containerChanged(self, arg0: FCurveContainer) -> None: ...
    @overload
    def containerChanged(self) -> Any: ...

class FCurve:
    class ChangeType:
        __members__: ClassVar[dict] = ...  # read-only
        __entries: ClassVar[dict] = ...
        cBegin: ClassVar[FCurve.ChangeType] = ...
        cEnd: ClassVar[FCurve.ChangeType] = ...
        cIntermediate: ClassVar[FCurve.ChangeType] = ...
        cNormal: ClassVar[FCurve.ChangeType] = ...
        def __init__(self, arg0: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        @property
        def name(self) -> str: ...
    cBegin: ClassVar[FCurve.ChangeType] = ...
    cEnd: ClassVar[FCurve.ChangeType] = ...
    cIntermediate: ClassVar[FCurve.ChangeType] = ...
    cNormal: ClassVar[FCurve.ChangeType] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...
    def clear(self) -> None: ...
    @overload
    def clearProperties(self) -> None: ...
    @overload
    def clearProperties(self) -> Any: ...
    def copy(self) -> FCurve: ...
    def eval(self, arg0: float) -> float: ...
    def evalAcceleration(self, arg0: float) -> float: ...
    def evalVelocity(self, arg0: float) -> float: ...
    def findSegment(self, *args, **kwargs): ...
    def getKeyframes(self) -> list: ...
    def getName(self) -> str: ...
    def getProperties(self) -> dict: ...
    def getProperty(self, arg0: str) -> str: ...
    def getSegments(self) -> list: ...
    @overload
    def insertSegment(self) -> Any: ...
    @overload
    def insertSegment(self) -> Any: ...
    def notifyChanged(self) -> None: ...
    @overload
    def removeSegment(self, arg0) -> None: ...
    @overload
    def removeSegment(self) -> Any: ...
    @overload
    def setChangeType(self, arg0: int) -> None: ...
    @overload
    def setChangeType(self) -> Any: ...
    def setName(self, arg0: str) -> None: ...
    def setProperty(self, arg0: str, arg1: str) -> bool: ...
    def sizeProperties(self) -> int: ...
    def subscribe(self, arg0) -> None: ...
    @overload
    @classmethod
    def subscribeGlobal(cls, arg0) -> None: ...
    @overload
    @classmethod
    def subscribeGlobal(cls) -> Any: ...
    def swap(self, arg0: FCurve) -> None: ...
    @overload
    def unsubscribe(self, arg0) -> None: ...
    @overload
    def unsubscribe(self) -> Any: ...
    @overload
    @classmethod
    def unsubscribeGlobal(cls, arg0) -> None: ...
    @overload
    @classmethod
    def unsubscribeGlobal(cls) -> Any: ...
    def __bool__(self) -> bool: ...
    def __copy__(self) -> FCurve: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...

class FCurveContainer:
    def __init__(self) -> None: ...
    def addCurve(self, arg0: FCurve) -> None: ...
    def clear(self) -> None: ...
    @overload
    def clearProperties(self) -> None: ...
    @overload
    def clearProperties(self) -> Any: ...
    def getCurves(self) -> list: ...
    def getProperties(self) -> dict: ...
    def getProperty(self, arg0: str) -> str: ...
    @overload
    def readCurves(self, arg0: str) -> None: ...
    @overload
    def readCurves(self) -> Any: ...
    @overload
    def readCurves(self) -> Any: ...
    @overload
    def readCurves(self) -> Any: ...
    @overload
    def readCurves(self) -> Any: ...
    def removeCurve(self, arg0: FCurve) -> None: ...
    def setProperty(self, arg0: str, arg1: str) -> bool: ...
    def size(self) -> int: ...
    def sizeProperties(self) -> int: ...
    def subscribe(self, arg0) -> None: ...
    @overload
    def unsubscribe(self, arg0) -> None: ...
    @overload
    def unsubscribe(self) -> Any: ...
    def writeCurves(self, arg0: str, arg1: str) -> None: ...
    def __bool__(self) -> bool: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...

class FCurveObserver:
    class CurveIntrinsicType:
        __members__: ClassVar[dict] = ...  # read-only
        __entries: ClassVar[dict] = ...
        cAssigned: ClassVar[FCurveObserver.CurveIntrinsicType] = ...
        cCleared: ClassVar[FCurveObserver.CurveIntrinsicType] = ...
        cNameChanged: ClassVar[FCurveObserver.CurveIntrinsicType] = ...
        cSwapped: ClassVar[FCurveObserver.CurveIntrinsicType] = ...
        def __init__(self, arg0: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        @property
        def name(self) -> str: ...

    class KeyframeIntrinsicType:
        __members__: ClassVar[dict] = ...  # read-only
        __entries: ClassVar[dict] = ...
        cBreakdownChanged: ClassVar[FCurveObserver.KeyframeIntrinsicType] = ...
        cPositionChanged: ClassVar[FCurveObserver.KeyframeIntrinsicType] = ...
        cUnifiedChanged: ClassVar[FCurveObserver.KeyframeIntrinsicType] = ...
        def __init__(self, arg0: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        @property
        def name(self) -> str: ...

    class SegmentIntrinsicType:
        __members__: ClassVar[dict] = ...  # read-only
        __entries: ClassVar[dict] = ...
        cInterpolatorChanged: ClassVar[FCurveObserver.SegmentIntrinsicType] = ...
        def __init__(self, arg0: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        @property
        def name(self) -> str: ...

    class TangentIntrinsicType:
        __members__: ClassVar[dict] = ...  # read-only
        __entries: ClassVar[dict] = ...
        cLockedWeightChanged: ClassVar[FCurveObserver.TangentIntrinsicType] = ...
        cTypeChanged: ClassVar[FCurveObserver.TangentIntrinsicType] = ...
        cVectorChanged: ClassVar[FCurveObserver.TangentIntrinsicType] = ...
        cWeightedChanged: ClassVar[FCurveObserver.TangentIntrinsicType] = ...
        def __init__(self, arg0: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        @property
        def name(self) -> str: ...
    cAssigned: ClassVar[FCurveObserver.CurveIntrinsicType] = ...
    cBreakdownChanged: ClassVar[FCurveObserver.KeyframeIntrinsicType] = ...
    cCleared: ClassVar[FCurveObserver.CurveIntrinsicType] = ...
    cInterpolatorChanged: ClassVar[FCurveObserver.SegmentIntrinsicType] = ...
    cLockedWeightChanged: ClassVar[FCurveObserver.TangentIntrinsicType] = ...
    cNameChanged: ClassVar[FCurveObserver.CurveIntrinsicType] = ...
    cPositionChanged: ClassVar[FCurveObserver.KeyframeIntrinsicType] = ...
    cSwapped: ClassVar[FCurveObserver.CurveIntrinsicType] = ...
    cTypeChanged: ClassVar[FCurveObserver.TangentIntrinsicType] = ...
    cUnifiedChanged: ClassVar[FCurveObserver.KeyframeIntrinsicType] = ...
    cVectorChanged: ClassVar[FCurveObserver.TangentIntrinsicType] = ...
    cWeightedChanged: ClassVar[FCurveObserver.TangentIntrinsicType] = ...
    def __init__(self) -> None: ...
    @overload
    def beginValueChange(self, arg0: FCurve) -> None: ...
    @overload
    def beginValueChange(self) -> Any: ...
    def curveChanged(self, arg0: FCurve) -> None: ...
    def curveIntrinsicChanged(self, arg0: FCurve, arg1) -> None: ...
    def curvePropertyChanged(self, arg0: FCurve, arg1: str, arg2: str) -> None: ...
    @overload
    def endValueChange(self, arg0: FCurve) -> None: ...
    @overload
    def endValueChange(self) -> Any: ...
    @overload
    def intermediateValueChange(self, arg0: FCurve) -> None: ...
    @overload
    def intermediateValueChange(self) -> Any: ...
    def keyframeChanged(self, arg0: Keyframe) -> None: ...
    def keyframeIntrinsicChanged(self, arg0: Keyframe, arg1) -> None: ...
    def keyframePropertyChanged(self, arg0: Keyframe, arg1: str, arg2: str) -> None: ...
    def segmentAdded(self, arg0: FCurve, arg1: Segment) -> None: ...
    def segmentChanged(self, arg0: Segment) -> None: ...
    def segmentIntrinsicChanged(self, arg0: Segment, arg1) -> None: ...
    def segmentPropertyChanged(self, arg0: Segment, arg1: str, arg2: str) -> None: ...
    def segmentRemoved(self, arg0: FCurve, arg1: Segment) -> None: ...
    def tangentChanged(self, arg0: Tangent) -> None: ...
    def tangentIntrinsicChanged(self, arg0: Tangent, arg1) -> None: ...
    def tangentPropertyChanged(self, arg0: Tangent, arg1: str, arg2: str) -> None: ...

class Interpolator:
    def __init__(self, *args, **kwargs) -> None: ...
    def __call__(self) -> float: ...

class Keyframe:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...
    @overload
    def clearProperties(self) -> None: ...
    @overload
    def clearProperties(self) -> Any: ...
    def get(self) -> tuple: ...
    def getInTangent(self, *args, **kwargs): ...
    def getLeftSegment(self) -> Segment: ...
    @classmethod
    def getMinSeparation(cls) -> float: ...
    def getOutTangent(self, *args, **kwargs): ...
    def getOwningCurve(self) -> FCurve: ...
    def getProperties(self) -> dict: ...
    def getProperty(self, key: str) -> str: ...
    def getRightSegment(self) -> Segment: ...
    def getSegments(self) -> tuple: ...
    def getTangents(self) -> tuple: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    def isBreakdown(self) -> bool: ...
    def isTangentsUnified(self) -> bool: ...
    def set(self, x: float, y: float) -> None: ...
    def setBreakdown(self, arg0: bool) -> None: ...
    def setProperty(self, key: str, value: str) -> bool: ...
    def setTangentsUnified(self, arg0: bool) -> None: ...
    def setX(self, arg0: float) -> None: ...
    @overload
    def setY(self, arg0: float) -> None: ...
    @overload
    def setY(self, y) -> Any: ...
    def sizeProperties(self) -> int: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...

class ParentSelectionObserver:
    def __init__(self, *args, **kwargs) -> None: ...

class Segment:
    def __init__(self) -> None: ...
    @overload
    def clearProperties(self) -> None: ...
    @overload
    def clearProperties(self) -> Any: ...
    def eval(self, arg0: float) -> float: ...
    def getExpression(self) -> str: ...
    def getFirstDerivative(self, arg0: float) -> float: ...
    def getInTangent(self, *args, **kwargs): ...
    def getKeys(self) -> tuple: ...
    def getLeftKey(self, *args, **kwargs): ...
    def getOutTangent(self, *args, **kwargs): ...
    def getOwningCurve(self) -> FCurve: ...
    def getProperties(self) -> dict: ...
    def getProperty(self, arg0: str) -> str: ...
    def getRangeExtents(self, arg0: float, arg1: float) -> tuple: ...
    def getRightKey(self, *args, **kwargs): ...
    def getSecondDerivative(self, arg0: float) -> float: ...
    def getTangents(self) -> tuple: ...
    def setExpression(self, arg0: str) -> None: ...
    def setProperty(self, arg0: str, arg1: str) -> None: ...
    def sizeProperties(self) -> int: ...
    def usesTangents(self) -> bool: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...

class Selection:
    def __init__(self, arg0: FCurveContainer) -> None: ...
    def clear(self) -> None: ...
    @overload
    def deselect(self, arg0: FCurve) -> None: ...
    @overload
    def deselect(self, arg0: Segment) -> None: ...
    @overload
    def deselect(self, arg0: Keyframe) -> None: ...
    @overload
    def deselect(self, arg0: Tangent) -> None: ...
    def getCurves(self) -> FCurveContainer: ...
    def getSelectedCurves(self) -> list: ...
    def getSelectedKeyframes(self) -> list: ...
    def getSelectedSegments(self) -> list: ...
    def getSelectedTangents(self) -> list: ...
    @overload
    def isSelected(self, arg0: FCurve) -> bool: ...
    @overload
    def isSelected(self, arg0: Segment) -> bool: ...
    @overload
    def isSelected(self, arg0: Keyframe) -> bool: ...
    @overload
    def isSelected(self, arg0: Tangent) -> bool: ...
    @overload
    def select(self, arg0: FCurve) -> None: ...
    @overload
    def select(self, arg0: Segment) -> None: ...
    @overload
    def select(self, arg0: Keyframe) -> None: ...
    @overload
    def select(self, arg0: Tangent) -> None: ...
    def subscribe(self, observer) -> None: ...
    @overload
    def unsubscribe(self, observer) -> None: ...
    @overload
    def unsubscribe(self) -> Any: ...

class SelectionObserver(ParentSelectionObserver):
    def __init__(self) -> None: ...
    @overload
    def deselected(self, arg0: FCurve) -> None: ...
    @overload
    def deselected(self) -> Any: ...
    @overload
    def deselected(self, arg0: Segment) -> None: ...
    @overload
    def deselected(self) -> Any: ...
    @overload
    def deselected(self, arg0: Keyframe) -> None: ...
    @overload
    def deselected(self) -> Any: ...
    @overload
    def deselected(self, arg0: Tangent) -> None: ...
    @overload
    def deselected(self) -> Any: ...
    @overload
    def selected(self, arg0: FCurve) -> None: ...
    @overload
    def selected(self) -> Any: ...
    @overload
    def selected(self, arg0: Segment) -> None: ...
    @overload
    def selected(self) -> Any: ...
    @overload
    def selected(self, arg0: Keyframe) -> None: ...
    @overload
    def selected(self) -> Any: ...
    @overload
    def selected(self, arg0: Tangent) -> None: ...
    @overload
    def selected(self) -> Any: ...
    @overload
    def selectionCleared(self) -> None: ...
    @overload
    def selectionCleared(self) -> Any: ...

class Tangent:
    class TangentType:
        __members__: ClassVar[dict] = ...  # read-only
        __entries: ClassVar[dict] = ...
        cClamped: ClassVar[Tangent.TangentType] = ...
        cFixed: ClassVar[Tangent.TangentType] = ...
        cFlat: ClassVar[Tangent.TangentType] = ...
        cLinear: ClassVar[Tangent.TangentType] = ...
        cSmooth: ClassVar[Tangent.TangentType] = ...
        cSmoothNormal: ClassVar[Tangent.TangentType] = ...
        def __init__(self, arg0: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        @property
        def name(self) -> str: ...
    cClamped: ClassVar[Tangent.TangentType] = ...
    cFixed: ClassVar[Tangent.TangentType] = ...
    cFlat: ClassVar[Tangent.TangentType] = ...
    cLinear: ClassVar[Tangent.TangentType] = ...
    cSmooth: ClassVar[Tangent.TangentType] = ...
    cSmoothNormal: ClassVar[Tangent.TangentType] = ...
    def __init__(self) -> None: ...
    @overload
    def clearProperties(self) -> None: ...
    @overload
    def clearProperties(self) -> Any: ...
    def get(self) -> tuple: ...
    def getAngle(self) -> float: ...
    def getOpposingTangent(self) -> Tangent: ...
    def getOwningCurve(self) -> FCurve: ...
    def getOwningKeyframe(self) -> Keyframe: ...
    def getOwningSegment(self) -> Segment: ...
    def getProperties(self) -> dict: ...
    def getProperty(self, key: str) -> str: ...
    def getType(self, *args, **kwargs): ...
    def getWeight(self) -> float: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    def isInTangent(self) -> bool: ...
    def isWeightLocked(self) -> bool: ...
    def isWeighted(self) -> bool: ...
    def set(self, x: float, y: float) -> None: ...
    def setAngle(self, angle: float) -> None: ...
    def setProperty(self, key: str, value: str) -> bool: ...
    def setType(self, type) -> None: ...
    def setWeight(self, weight: float) -> None: ...
    def setWeightLocked(self, arg0: bool) -> None: ...
    def setWeighted(self, arg0: bool) -> None: ...
    def setX(self, x: float) -> None: ...
    def setY(self, y: float) -> None: ...
    def sizeProperties(self) -> int: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other: object) -> bool: ...

def GetGridSettings(curve: FCurve) -> tuple: ...
def GetNamespace() -> dict: ...
def HasGridSettings(curve: FCurve) -> bool: ...
def IsEditable(curve: FCurve) -> bool: ...
@overload
def IsLocked(curve: FCurve) -> bool: ...
@overload
def IsLocked(keyframe: Keyframe) -> bool: ...
def IsVisible(curve: FCurve) -> bool: ...
def ReadContainerFromString(string: str, container: FCurveContainer = ...) -> FCurveContainer: ...
def ReadFromBinaryString(binaryString: str, curve: FCurve = ...) -> FCurve: ...
def ReadFromXMLString(xmlString: str, curve: FCurve = ...) -> FCurve: ...
def RemoveGridSettings(curve: FCurve) -> None: ...
def SetEditable(curve: FCurve, isEditable: bool) -> None: ...
@overload
def SetGridSettings(arg0: FCurve, arg1: list[tuple[float, float, float, float]]) -> None: ...
@overload
def SetGridSettings(arg0: FCurve, arg1: float, arg2: float, arg3: float, arg4: float) -> None: ...
@overload
def SetLocked(curve: FCurve, isLocked: bool) -> None: ...
@overload
def SetLocked(keyframe: Keyframe, isLocked: bool) -> None: ...
def SetVisible(curve: FCurve, isVisible: bool) -> None: ...
def WriteContainerToString(container: FCurveContainer, format: str = ...) -> bytes: ...
def WriteToBinaryString(curve: FCurve) -> bytes: ...
def WriteToXMLString(curve: FCurve) -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import RenderingAPI as RenderingAPI
from RenderingAPI.RenderPlugins import GetRenderMethodsForRenderer as GetRenderMethodsForRenderer
from typing import Set, Tuple

class RenderingException(Exception):
    def __init__(self, sequenceID, errorCode, nodeName, message) -> None: ...

class UnsupportedRenderMethodNameException(Exception):
    def __init__(self, rendererName, renderMethodName) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import UI4.Util.FileHelpers as FileHelpers
import UI4.KatanaPrefs.PrefNames as PrefNames
import Utils as Utils
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from typing import Set, Tuple

def ClearRecentFiles(): ...
def GetAllRecentFiles() -> list[str]: ...
def OpenRecentFileByIndex(recentFileIndex: int): ...
def PushRecentFile(fileName): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class ContextMenuHelper:
    def __init__(self, tree, event) -> None: ...
    def __enter__(self): ...
    def __exit__(self, *args): ...

class UpdateSuppressor:
    def __init__(self, treeWidget) -> None: ...
    def __enter__(self): ...
    def __exit__(self, *args): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyUtilModule.UserNodes as UserNodes
from . import NodeInteractionDelegateManager as NodeInteractionDelegateManager, NodeInteractionDelegates as NodeInteractionDelegates
from typing import Set, Tuple

_Initialized: bool

def Initialize(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def TraceCall(loggerOrFunction: Incomplete | None = ...): ...
def stacktrace(_name): ...
def undogroup(_name): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
from typing import Set, Tuple

class SuperDelegate:
    def processNodeCreate(self, node: NodegraphAPI.Node): ...

def RegisterSuperDelegate(delegate): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModule as EventModule
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class WorkQueue:
    class QueueAbort(Exception): ...
    def __init__(self, busyProcess: Incomplete | None = ...) -> None: ...
    def _WorkQueue__disable(self, cleanExit): ...
    def _WorkQueue__enable(self): ...
    def _WorkQueue__idleCB(self, *args, **kwargs): ...
    def addWork(self, fcn, *args, **kwargs): ...
    def addWorkToFront(self, fcn, *args, **kwargs): ...
    def busy(self): ...
    def checkAbort(self): ...
    def empty(self): ...
    def finishWork(self): ...
    def report(self): ...
    def workCompletedCleanExit(self): ...
    def workCompletedEarlyExit(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.Node3D import Node3D as Node3D
from PyUtilModule.WorkingSet import WorkingSet as WorkingSet
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from typing import ClassVar, Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class WorkingSetDebugNode(Node3D):
    _WorkingSetDebugNode__OutputAttributeName: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def _WorkingSetDebugNode__locationStateChangedCallback(self, locationStateChanges, workingSet, sender): ...
    def _WorkingSetDebugNode__updateWorkingSet(self, workingSetName): ...
    def _WorkingSetDebugNode__updateWorkingSetParams(self, workingSet): ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...

def __GetWorkingSetContentsChildren(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import QT4Widgets.SortableTreeWidget
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import Utils as Utils
import QT4Widgets.WidgetUtils as WidgetUtils
from QT4Widgets.SortableTreeWidget import SortableTreeWidget
from UI4.Widgets.DoubleClickSizeGrip import DoubleClickSizeGrip as DoubleClickSizeGrip
from UI4.Widgets.ScrollAreaMemory import ScrollAreaMemory as ScrollAreaMemory
from UI4.Widgets.SortableListWidget import SortableListWidget as SortableListWidget, SortableListWidgetItem as SortableListWidgetItem
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class AllViewDelegate(QT4Widgets.SortableTreeWidget.SortableTreeWidgetItemDelegate):
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...

class CategoryTreeWidgetItem(QT4Widgets.SortableTreeWidget.SortableTreeWidgetItem):
    def isDraggable(self): ...

class DoubleClickTreeWidget(SortableTreeWidget):
    itemDoubleClick: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def mouseDoubleClickEvent(self, event): ...

class RenderModePopup(PyQt5.QtWidgets.QFrame):
    hideSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    showSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    updateSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _RenderModePopup__activeListAboutToDrag(self, selectedItems, dragObject): ...
    def _RenderModePopup__activeListDragEnter(self, event): ...
    def _RenderModePopup__activeListDropEventCallback(self, event, toIndex): ...
    def _RenderModePopup__activeListFocusIn(self, event): ...
    def _RenderModePopup__activeListKeyPress(self, event): ...
    def _RenderModePopup__activeListReorderItemsCallback(self, fromIndices, toIndex): ...
    def _RenderModePopup__activeListSelectCallback(self): ...
    def _RenderModePopup__addNodeToActiveList(self, nodeName, toIndex: Incomplete | None = ...): ...
    def _RenderModePopup__addToActiveList(self): ...
    def _RenderModePopup__allListAboutToDrag(self, selectedItems, dragObject): ...
    def _RenderModePopup__allListDoubleClick(self, item, event): ...
    def _RenderModePopup__allListDragEnter(self, event): ...
    def _RenderModePopup__allListDropEventCallback(self, event): ...
    def _RenderModePopup__allListGetSelectedNodeNames(self): ...
    def _RenderModePopup__allListGetSortedItems(self, selectedOnly: bool = ...): ...
    def _RenderModePopup__allListKeyPress(self, event): ...
    def _RenderModePopup__allListRecursiveGetItems(self, item, selectedOnly: bool = ...): ...
    def _RenderModePopup__buildWidgets(self): ...
    def _RenderModePopup__clearActiveList(self): ...
    def _RenderModePopup__finalizeValueHandler(self, args): ...
    def _RenderModePopup__getActiveList(self): ...
    def _RenderModePopup__nodeCreated(self, args): ...
    def _RenderModePopup__nodeDeleted(self, args): ...
    def _RenderModePopup__removeNodeFromActiveList(self, nodeName): ...
    def _RenderModePopup__setActiveList(self, activeNodes): ...
    def _RenderModePopup__updateFilter(self): ...
    def applyDefaultSize(self): ...
    def hideEvent(self, e): ...
    def popup(self, globalPos): ...
    def showEvent(self, e): ...
    def update(self): ...

class RenderModePopupButton(ToolbarButton):
    popupClosed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, buttonType: Incomplete | None = ...) -> None: ...
    def _RenderModePopupButton__popClicked(self): ...
    def _RenderModePopupButton__popupHidden(self): ...
    def _RenderModePopupButton__popupShow(self): ...
    def _RenderModePopupButton__update(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtCore
import PyQt5.QtGui
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.FWidget import FBoxLayout as FBoxLayout, FButton as FButton, FDisclosureTriangle as FDisclosureTriangle, FLabel as FLabel, FLockIcon as FLockIcon, FMenu as FMenu, FPixmap as FPixmap, FSpacer as FSpacer, FStateBadge as FStateBadge, FSvgIcon as FSvgIcon, FToggleStateBadge as FToggleStateBadge, FWidget as FWidget
from QT4FormWidgets.FormWidget import AlignChildLabelWidths as AlignChildLabelWidths, AlignLeftControlWidths as AlignLeftControlWidths, FormWidget as FormWidget, ScrubbingStates as ScrubbingStates
from QT4FormWidgets.MultiStateBadge import MultiStateBadge as MultiStateBadge, ToggleStateBadge as ToggleStateBadge, ToggleValuePolicyState as ToggleValuePolicyState
from QT4FormWidgets.NumberFormWidget import CreateSensitivityMenu as CreateSensitivityMenu, FormatNumber as FormatNumber, NumberFormWidget as NumberFormWidget
from QT4FormWidgets.StringFormWidget import StringFormWidget as StringFormWidget
from QT4FormWidgets.ValuePolicy import ValuePolicyEvent as ValuePolicyEvent
from typing import ClassVar, Set, Tuple

class GroupFormWidget(FormWidget):
    _GroupFormWidget__STYLEMAP: ClassVar[dict] = ...
    groupWidgetClosed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _GroupFormWidget__syncChildren(self): ...
    def _buildControlWidget(self, layout): ...
    def _buildInfoWidget(self): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _buildLock(self, layout): ...
    def _createChildWidget(self, policy, parentWidget, factory, index): ...
    def _firstChildFormWidgetIndex(self): ...
    def _freeze(self): ...
    def _lockChanged(self, state): ...
    def _participatesInLabelAlignment(self): ...
    def _popdownCreated(self, popdown): ...
    def _thaw(self): ...
    def alignChildLabelWidths(self): ...
    def closeEvent(self, event: PyQt5.QtGui.QCloseEvent): ...
    def setLabelWidth(self, labelWidth): ...
    def showPopdown(self, value): ...
    def valueChangedEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.InputWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
from QT4FormWidgets.FilterablePopupFormWidget import FilterablePopupFormWidget
from QT4FormWidgets.FilterablePopupFormWidget.FilterablePopupFormWidget import Popup
from QT4FormWidgets.WidgetFactory import WidgetFactory
from typing import Set, Tuple

class HintedFilterablePopupFormWidget(FilterablePopupFormWidget):
    class ControlComboBox(QT4FormWidgets.InputWidgets.InputComboBox):
        def __init__(self, parent: QT4FormWidgets.FormWidget) -> None: ...
        def _ControlComboBox__on_editingFinished(self): ...
        def _ControlComboBox__on_filterPopup_hide(self): ...
        def _ControlComboBox__on_filterPopup_itemChosen(self, text, meta): ...
        def _ControlComboBox__on_filterPopup_show(self): ...
        def keyPressEvent(self, event: PyQt5.QtGui.QKeyEvent): ...
        def setEditable(self, editable: bool): ...
        def showPopup(self): ...

    class Popup(Popup):
        def _refreshContents(self): ...
        def _selectCurrentValue(self): ...
        def refresh(self, force: bool = ...): ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, factory: WidgetFactory) -> None: ...
    def _buildControlWidget(self, layout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _buildPopupWindow(self): ...
    def _lockChanged(self, state): ...
    def _updateControlWidget(self): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def getComboBox(self) -> PyQt5.QtWidgets.QComboBox: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibServices.ExpressionMath as ExpressionMath
import PyFnGeolibServices as FnGeolibServices
import GeoAPI as GeoAPI
import NodegraphAPI as NodegraphAPI
import PyOpenColorIO as OCIO
import PyFCurve as PyFCurve
import PyXmlIO as PyXmlIO
import PyResolutionTableFn as ResolutionTable
import Naming as UniqueName
import Utils as Utils
import PyXmlIO as XmlIO
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import KatanaResources as KatanaResources
import UI4.FormMaster.NodeMimeData as NodeMimeData
import NodegraphAPI as NodegraphAPI
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
import typing
from NodegraphAPI.LiveGroup import LiveGroupMixin as LiveGroupMixin
from PyUtilModule.VirtualKatana import Widgets as Widgets
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from UI4.Tabs.NodeGraphTab.NodeGoRootButton import NodeGoRootButton as NodeGoRootButton
from UI4.Widgets.NodeButton import NodeButton as NodeButton
from UI4.Widgets.NodePopupMenu import NodePopupMenu as NodePopupMenu
from _typeshed import Incomplete
from typing import Set, Tuple

__liveGroupPixmapNames: dict
__nodePixmaps: dict

class NodeBreadcrumbsFrame(PyQt5.QtWidgets.QFrame):
    def __init__(self, enterGroupNodeCallback: typing.Optional[typing.Callable] = ..., goToNodeCallback: typing.Optional[typing.Callable] = ..., parent: Incomplete | None = ...) -> None: ...
    def _NodeBreadcrumbsFrame__addFrameWidgets(self, frameWidgets: list, groupNodes: list[NodegraphAPI.GroupNode]) -> list[NodegraphAPI.GroupNode]: ...
    def _NodeBreadcrumbsFrame__enterOrRevealNode(self, node: NodegraphAPI.Node): ...
    def _NodeBreadcrumbsFrame__insertFrameWidgets(self, frameWidgets: list, insertionIndex: int, groupNode: Incomplete | None = ..., lastNode: bool = ...) -> bool: ...
    def _NodeBreadcrumbsFrame__on_nodeButton_clicked(self): ...
    def _NodeBreadcrumbsFrame__on_node_updated(self, args: list[tuple[str, object, dict]]): ...
    def _NodeBreadcrumbsFrame__removeFrameWidgets(self): ...
    def _NodeBreadcrumbsFrame__updateNodeButtons(self): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def fontChange(self, oldFont): ...
    def getDeepestNotDeletedNode(self) -> list[NodegraphAPI.Node]: ...
    def resizeEvent(self, event): ...
    def setCurrentNodeView(self, groupNode: NodegraphAPI.GroupNode | None): ...
    def showEvent(self, event: PyQt5.QtGui.QShowEvent): ...

class _EllipsisPopupButton(FilterablePopupButton):
    def __init__(self, enterGroupNodeCallback: callback, parent: Incomplete | None = ...) -> None: ...
    def _EllipsisPopupButton__on_itemChosen(self, name, meta: Incomplete | None = ...): ...
    def _EllipsisPopupButton__on_node_setColor(self, eventType, eventID, **kwargs): ...
    def _EllipsisPopupButton__on_popupAboutToShow(self): ...
    def _EllipsisPopupButton__on_popupWindowTreeWidget_mousePressEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def _EllipsisPopupButton__on_popupWindowTreeWidget_rightClick(self, event: PyQt5.QtGui.QMouseEvent): ...
    def setGroupNodes(self, groupNodes): ...

class _SeparatorLabel(PyQt5.QtWidgets.QLabel):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...

def _GetNodePixmap(node: NodegraphAPI.Node) -> PyQt5.QtGui.QPixmap: ...
def _InitNodePixmaps(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
from UI4.Util.AbstractSyntaxHighlighter import AbstractSyntaxHighlighter as AbstractSyntaxHighlighter
from typing import Set, Tuple

class PythonSyntaxHighlighter(AbstractSyntaxHighlighter):
    def __init__(self, document: PyQt5.QtWidgets.QTextEdit | PyQt5.QtGui.QTextDocument | PyQt5.QtCore.QObject, baseFormat: PyQt5.QtGui.QTextCharFormat, interpreterInputOnly: bool = ...) -> None: ...
    def _createCustomBlocks(self): ...
    def _createFormats(self): ...
    def _createPostBlockRules(self): ...
    def _createRules(self): ...
    def highlightBlock(self, text: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from UI4.Widgets.VerticalDivider import VerticalDivider as VerticalDivider
from typing import ClassVar, Set, Tuple

class ToolbarWidget(PyQt5.QtWidgets.QWidget):
    toolbarChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _ToolbarWidget__toolbarChoiceTriggered_CB(self, action): ...
    def _ToolbarWidget__updateToolbar(self): ...
    def addToolbar(self, toolbar): ...
    def popToolbar(self, toolbar): ...
    def removeToolbar(self, toolbar): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4GLLayerStack.LayerStack import Layer as Layer
from typing import Set, Tuple

class PanInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, name, *args, **kwargs) -> None: ...
    def freeze(self): ...
    def processEvent(self, e): ...
    def setAllowKeylessTabletInteraction(self, allowKeylessTabletInteraction): ...
    def setHorizontalLock(self, isLocked): ...
    def setVerticalLock(self, isLocked): ...
    def thaw(self): ...

class PanTransientLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, event, horizontalLock, verticalLock, prevFocusLayer, *args, **kwargs) -> None: ...
    def _PanTransientLayer__setup(self): ...
    def freeze(self): ...
    def processEvent(self, e): ...
    def setLayerStack(self, s): ...
    def thaw(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import HydraViewer.ManipulatorManager
import UI4.Widgets.LightingToolsLayer.LightingToolsUtils as LightingToolsUtils
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import RenderingAPI.RenderPlugins as RenderPlugins
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import UI4 as UI4
import QT4Widgets.WidgetUtils as WidgetUtils
from PyUtilModule.VirtualKatana import QtCore as QtCore, QtGui as QtGui, QtWidgets as QtWidgets
from UI4.Widgets.DropdownArrowButton import DropdownArrowButton as DropdownArrowButton
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LightPackagesGroup(PyQt5.QtWidgets.QWidget):
    kButtonPadding: ClassVar[tuple] = ...
    triggered: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, rendererPluginName, rendererDisplayName, buttonGroup, lights, parent: Incomplete | None = ...) -> None: ...
    def buttons(self) -> list[PyQt5.QtWidgets.QAbstractButton]: ...

class LightPackagesMenu(PyQt5.QtWidgets.QWidget):
    aboutToHide: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    rebuilt: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    triggered: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _LightPackagesMenu__createCloneButtons(self): ...
    def _LightPackagesMenu__createGearButton(self): ...
    def _LightPackagesMenu__createGearMenu(self): ...
    def _LightPackagesMenu__createPackageGroup(self, pluginName: str, displayName: str): ...
    def _LightPackagesMenu__createPlaceholderText(self, text: str) -> PyQt5.QtWidgets.QLabel: ...
    def _LightPackagesMenu__getEnabledRenderers(self) -> list[None]: ...
    def _LightPackagesMenu__onCloneButtonToggled(self, checked: bool): ...
    def _LightPackagesMenu__onGearButtonClicked(self, *args): ...
    def _LightPackagesMenu__onGearCheckBoxToggled(self, pluginName: str, enabled: bool): ...
    def _LightPackagesMenu__onLightPackageGroupTriggered(self, packageButton: PyQt5.QtWidgets.QAbstractButton): ...
    def _LightPackagesMenu__rebuildCloneButtonLayout(self, useHorizontal: bool): ...
    def _LightPackagesMenu__selectFirstPackageForGroup(self, targetPluginName: str): ...
    def _LightPackagesMenu__selectPackageButton(self, packageButton: PyQt5.QtWidgets.QAbstractButton, enabled: bool): ...
    def closeEvent(self, event: PyQt5.QtGui.QCloseEvent): ...
    def getSelectedPackageInfo(self) -> None: ...
    def mouseMoveEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def mouseReleaseEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def popup(self, point: PyQt5.QtCore.Qt.QPoint): ...
    def resizeEvent(self, event: PyQt5.QtGui.QResizeEvent): ...

class LightingToolsToolBar(PyQt5.QtWidgets.QToolBar):
    class MenuEntry:
        def __init__(self, text, iconStem) -> None: ...
    kDefaultLightingModeIndex: ClassVar[int] = ...
    kLightingModes: ClassVar[list] = ...
    triggered: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, tab, manipulatorManager, height) -> None: ...
    @staticmethod
    def _LightingToolsToolBar__computeMenuPosition(menu: PyQt5.QtWidgets.QMenu, widget: PyQt5.QtWidgets.QWidget) -> PyQt5.QtCore.QPoint: ...
    def _LightingToolsToolBar__createDropdownButton(self, height: int) -> LightingToolsDropdownButton: ...
    def _LightingToolsToolBar__createLightPackagesButton(self, height: int) -> PyQt5.QtWidgets.QToolButton: ...
    def _LightingToolsToolBar__createLightPackagesMenu(self) -> PyQt5.QtWidgets.QMenu: ...
    def _LightingToolsToolBar__createLightingModeButton(self, height: int) -> ToolbarButton: ...
    def _LightingToolsToolBar__createLightingModeIcon(self, menuEntry: MenuEntry) -> PyQt5.QtWidgets.QIcon: ...
    def _LightingToolsToolBar__createLightingModeMenu(self) -> PyQt5.QtWidgets.QMenu: ...
    def _LightingToolsToolBar__emitChanges(self): ...
    def _LightingToolsToolBar__getDefaultLightingModeAction(self) -> PyQt5.QtWidgets.QAction: ...
    def _LightingToolsToolBar__getLightingModePixmaps(self, menuEntry: MenuEntry) -> None: ...
    def _LightingToolsToolBar__getManipulator(self) -> HydraViewer.ManipulatorManager.Manipulator: ...
    def _LightingToolsToolBar__onLightPackageChanged(self, packageButton): ...
    def _LightingToolsToolBar__onLightPackageMenuRebuilt(self): ...
    def _LightingToolsToolBar__onLightingModeChanged(self, action: PyQt5.QtWidgets.QAction): ...
    def _LightingToolsToolBar__onLightingModeToggled(self, enabled: bool, modeAction: PyQt5.QtWidgets.QAction): ...
    def _LightingToolsToolBar__onManipulatorToggled(self, enabled: bool): ...
    @staticmethod
    def _LightingToolsToolBar__showMenu(menu: PyQt5.QtWidgets.QMenu, widget: PyQt5.QtWidgets.QWidget): ...
    def _LightingToolsToolBar__syncButtonState(self): ...
    def _LightingToolsToolBar__updateToolTips(self): ...
    def cycleLightingMode(self): ...
    def getLightingMode(self) -> str: ...
    def getPackageClassName(self) -> str: ...
    def isEnabled(self) -> bool: ...
    def isFixedRotationEnabled(self) -> str: ...
    def setEnabled(self, enabled: bool): ...
    def setFixedRotationEnabled(self, enabled: bool): ...
    def setLightingMode(self, mode: PyQt5.QtWidgets.QAction | str, enabled: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI
import KatanaResources as KatanaResources
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
import _FnKatanaCoreUI as _FnKatanaCoreUI
import re
from AssetBrowser.FileInfo import FileInfo as FileInfo
from Utils.Decorators import deprecated as deprecated
from _FnKatanaCoreUI import FnFileBrowser as FnFileBrowser, FnFileSequenceEvaluator as FnFileSequenceEvaluator
from typing import ClassVar, Set, Tuple

class Browser(PyQt5.QtWidgets.QFrame):
    _FileSequenceEvaluator: ClassVar[FileSequenceEvaluator] = ...
    _FrameNumberVariableRegex: ClassVar[re.Pattern] = ...
    _HomeDirPath: ClassVar[str] = ...
    _PreferencesPath: ClassVar[str] = ...
    _ProductName: ClassVar[str] = ...
    _ProductPath: ClassVar[str] = ...
    _RootDirPath: ClassVar[str] = ...
    _TrailingFrameRangeRegex: ClassVar[re.Pattern] = ...
    acceptedSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    selectionValidSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None) -> None: ...
    @classmethod
    def AddQuickLinkPath(cls, quickLinkPath: str): ...
    @classmethod
    def ClearQuickLinks(cls): ...
    @classmethod
    def InitializeFileBrowser(cls): ...
    def _Browser__addGlobalQuickLinks(self): ...
    def _Browser__isFileSequence(self, filePath: str) -> bool: ...
    def _Browser__isValidPath(self, filePath: str) -> bool: ...
    def _Browser__removeTrailingFrameRange(self, filePath: str) -> str: ...
    def _Browser__setSelectionValid(self, selectionValid: bool): ...
    def _Browser__splitFilePath(self, filePath: str) -> Tuple[str, str]: ...
    def addQuickLinkPaths(self, quickLinkPaths: list[str]): ...
    def beginUpdate(self): ...
    def endUpdate(self): ...
    def getResult(self) -> str: ...
    def on_fileDoubleClick(self): ...
    def on_filenameTextChanged(self, filename: str): ...
    def selectionValid(self) -> bool: ...
    def setFileSequencePlugin(self, fileSequencePlugin: AssetAPI.FileSequencePlugin): ...
    def setFindSequenceFunc(self, findSequenceFunc): ...
    def setLocation(self, location: str): ...
    def setQuickLinkPaths(self, quickLinkPaths): ...
    def setSaveMode(self, saveModeEnabled: bool): ...
    def setSequenceListing(self, isSequenceListingEnabled: bool): ...
    def setTypes(self, types: list[str]): ...
    def setValidSelectionTypes(self, validSelectionTypes: list[int]): ...

class FileSequenceEvaluator(_FnKatanaCoreUI.Foundry.UI.FileSequenceEvaluator):
    def __init__(self) -> None: ...
    def _buildFileSequences(self, sequences: list[FileSequence], allFileInfosIndex) -> list[FnFileInfo]: ...
    def _getFrameFileInfo(self, sequence: FileSequence, frameNumber: int, allFileInfosIndex) -> FileInfo: ...
    def evaluateFiles(self, allFileInfos: list[FileInfo]) -> tuple[FileInfo, ...]: ...
    def setFileSequencePlugin(self, fileSequencePlugin: FileSequencePlugin): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import ImageLayerBase as ImageLayerBase
from UI4.Tabs.Monitor.Layers.CropWindowLayer import CropWindowLayer as CropWindowLayer
from UI4.Tabs.Monitor.Layers.HotkeyLayer import HotkeyLayer as HotkeyLayer
from UI4.Tabs.Monitor.Layers.ImageLayer import ImageLayer as ImageLayer
from UI4.Tabs.Monitor.Layers.ImageLayer3D import ImageLayer3D as ImageLayer3D
from UI4.Tabs.Monitor.Layers.LinearSwipeLayer import LinearSwipeLayer as LinearSwipeLayer
from UI4.Tabs.Monitor.Layers.MaskLayer import MaskLayer as MaskLayer
from UI4.Tabs.Monitor.Layers.PixelProbeLayer import PixelProbeLayer as PixelProbeLayer
from UI4.Tabs.Monitor.Layers.RectangleSwipeLayer import RectangleSwipeLayer as RectangleSwipeLayer
from UI4.Tabs.Monitor.Layers.RenderFocusLayer import RenderFocusLayer as RenderFocusLayer
from UI4.Tabs.Monitor.Layers.RoiLayer import RoiLayer as RoiLayer
from UI4.Tabs.Monitor.Layers.SolidBoundsLayer import SolidBoundsLayer as SolidBoundsLayer
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import UI4 as UI4
import Utils as Utils
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from _typeshed import Incomplete
from typing import Set, Tuple

GRIDSIZEX: int
GRIDSIZEY: int

class FloatingNodeLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def NodeDelete(self, node: NodegraphAPI.Node): ...
    def _FloatingNodeLayer__activeNodeHasDynamicInputs(self): ...
    def _FloatingNodeLayer__dropNodes(self): ...
    def _FloatingNodeLayer__findPhysicallyConnectedNodesForNode(self, node: NodegraphAPI.Node, inputPorts: bool = ..., maxDistance: int = ..., resultDict: Incomplete | None = ...): ...
    def _FloatingNodeLayer__getPortDistance(self, portA, portB): ...
    def _FloatingNodeLayer__hitTestPort(self, mousePoint): ...
    def _FloatingNodeLayer__nextActiveInputPort(self): ...
    def _FloatingNodeLayer__nextActiveOutputPort(self): ...
    def _FloatingNodeLayer__nodeFloatHandler(self, eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...
    def _FloatingNodeLayer__node_delete_cb(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _FloatingNodeLayer__processKeyPress(self, event): ...
    def _FloatingNodeLayer__processMouseButtonPress(self, event): ...
    def _FloatingNodeLayer__processMouseButtonRelease(self, event): ...
    def _FloatingNodeLayer__record_newNode_Undo(self, node: NodegraphAPI.Node): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def setBasePosition(self, pos): ...

def IsNodeAutoConnectable(node: NodegraphAPI.Node): ...
def IsPortAutoConnectable(port: NodegraphAPI.Port): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4 as UI4
import typing
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import Set, Tuple

class ResizeToggleArrow(ToolbarButton):
    def __init__(self, parent, target, getMaxSizeCallback: typing.Callable, horizontal: bool = ...) -> None: ...
    def _ResizeToggleArrow__clicked(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import ResourceFiles as ResourceFiles
from KatanaResources.ResourceFiles import DefaultResourcePath as DefaultResourcePath, GetIconPath as GetIconPath, GetResourceFile as GetResourceFile, GetSearchPaths as GetSearchPaths, GetUserKatanaPath as GetUserKatanaPath, Initialize as Initialize, InternalResourcePath as InternalResourcePath
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from NodegraphAPI.ParameterValueOption import AllLocations as AllLocations, CELLocations as CELLocations, ParameterValueOption as ParameterValueOption, SpecificLocation as SpecificLocation
from typing import Set, Tuple

AllOptions: list



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LabeledToolbarButton(PyQt5.QtWidgets.QWidget):
    class _ClickLabel(PyQt5.QtWidgets.QLabel):
        clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def mousePressEvent(self, event): ...
    toggled: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, label, parent, *args, **kwargs) -> None: ...
    def isOn(self): ...
    def setOn(self, on): ...

class ToolbarButton(PyQt5.QtWidgets.QPushButton):
    mousePressEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    rightClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, label, parent, normalPixmap, disabledPixmap: Incomplete | None = ..., rolloverPixmap: Incomplete | None = ..., onPixmap: Incomplete | None = ..., sizeFromPixmap: bool = ..., isToggle: bool = ..., disabledRolloverPixmap: Incomplete | None = ..., onRolloverPixmap: Incomplete | None = ..., errorPixmap: Incomplete | None = ..., errorRolloverPixmap: Incomplete | None = ..., clickAction: Incomplete | None = ...) -> None: ...
    def _ToolbarButton__actionToggled(self): ...
    def _ToolbarButton__update(self): ...
    def disabledPixmap(self): ...
    def disabledRolloverPixmap(self): ...
    def enterEvent(self, ev): ...
    def errorPixmap(self): ...
    def errorRolloverPixmap(self): ...
    def isEnabled(self): ...
    def isError(self): ...
    def isOn(self): ...
    def leaveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def normalPixmap(self): ...
    def onPixmap(self): ...
    def onRolloverPixmap(self): ...
    def rolloverPixmap(self): ...
    def setDisabledPixmap(self, p): ...
    def setDisabledRolloverPixmap(self, p): ...
    def setEnabled(self, value): ...
    def setError(self, value, toolTip: Incomplete | None = ...): ...
    def setErrorPixmap(self, p): ...
    def setErrorRolloverPixmap(self, p): ...
    def setNormalPixmap(self, p): ...
    def setOn(self, value): ...
    def setOnPixmap(self, p): ...
    def setOnRolloverPixmap(self, p): ...
    def setRolloverPixmap(self, p): ...
    def toggle(self): ...
    def triggerAction(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import DrawingModule as DrawingModule
import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from PyUtilModule.VirtualKatana import KatanaFile as KatanaFile
from typing import Set, Tuple

class DragAndDropLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _DragAndDropLayer__getDropNode(self, event): ...
    def _DragAndDropLayer__getGroup(self, event): ...
    def _DragAndDropLayer__handleFaceSetDrop(self, event): ...
    def _DragAndDropLayer__handleFileRefDrop(self, event): ...
    def _DragAndDropLayer__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _DragAndDropLayer__setDropNode(self, node: NodegraphAPI.Node): ...
    def _DragAndDropLayer__setHiliteGroup(self, group): ...
    def dragMoveEvent(self, event): ...
    def dropEvent(self, event): ...
    def dropPosition(self, parentNode, event): ...
    def paintGL(self): ...
    def processEvent(self, event): ...

def CatalogDialogPrompt(parent): ...
def GetCatalogItemFromEvent(event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import GeoAPI as GeoAPI
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Utils as Utils
from typing import ClassVar, Set, Tuple

class LayerWithTransform:
    _LayerWithTransform__identity: ClassVar[tuple] = ...
    def __init__(self, node: NodegraphAPI.Node) -> None: ...
    def _LayerWithTransform__freeze(self): ...
    def _LayerWithTransform__setupEventHandlers(self, enabled): ...
    def _LayerWithTransform__thaw(self): ...
    def _LayerWithTransform__transformPoint(self, matrix, point2D): ...
    def _LayerWithTransform__updateEditToMonitorTransform(self): ...
    def _LayerWithTransform__updateEditTransformCallback(self, args): ...
    def applyWorldSpace(self): ...
    def applyWorldSpaceWithDropShadow(self, screendx: float = ..., screendy: float = ...): ...
    def editTransformHasError(self): ...
    def getEditTransformErrorMessage(self): ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getViewScale(self): ...
    def mapFromQTLocalToWorld(self, qtLocalX, qtLocalY): ...
    def mapFromWindowToWorld(self, winX, winY): ...
    def mapFromWorldToQTLocal(self, layerX, layerY): ...
    def mapFromWorldToWindow(self, layerX, layerY): ...
    def updateEditTransform(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import GeoAPI as GeoAPI
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets as Widgets
from typing import Set, Tuple

class ArgsExportDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, shaderName, rendererInfoPluginName) -> None: ...
    def _ArgsExportDialog__fileToggleCallback(self): ...
    def _ArgsExportDialog__okClicked(self): ...
    def _ArgsExportDialog__publishToggleCallback(self): ...
    def _ArgsExportDialog__updateState(self): ...
    def _ArgsExportDialog__validityChangeCallback(self, state): ...
    def getResult(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI.CatalogItem
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class CatalogNameWidget(PyQt5.QtWidgets.QLabel):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _CatalogNameWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogNameWidget__catalog_itemPropertyUpdate_CB(self, eventType, eventID, item, **kwargs): ...
    def resizeEvent(self, event: PyQt5.QtGui.QResizeEvent): ...
    def setCatalogItem(self, catalogItem: CatalogAPI.CatalogItem.CatalogItem | None): ...
    def updateState(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def DefaultResourcePath(subdir: Incomplete | None = ...): ...
def GetIconPath(name: str) -> str | None: ...
def GetResourceFile(resourceName: str): ...
def GetSearchPaths(subdir: str = ...) -> list[str]: ...
def GetUserKatanaPath(subdir: str = ...) -> str: ...
def Initialize(): ...
def InternalResourcePath(subdir: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.GLDrawingRoutines as GLDrawingRoutines
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import UI4.Util.Events
import Utils as Utils
import collections
import enum
from UI4.Util.Events import EventProcessorHandler as EventProcessorHandler, LayerWorldDragEventProcessor as LayerWorldDragEventProcessor
from UI4.Util.TransformManipulatorLayer import TransformManipulatorLayer as TransformManipulatorLayer
from UI4.Util.TransformManipulatorLayer.TransformManipulatorLayer import COMPONENTS, COORDINATE_SYSTEM, PICK
from UI4.Util.UndoGrouping import UndoContextGuard as UndoContextGuard
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ParameterTransformGroupManipulator(TransformManipulatorLayer):
    _COMPONENTS_TO_PARAMS: ClassVar[dict] = ...
    _PARAMS_TO_COMPONENTS: ClassVar[dict] = ...
    def __init__(self, valuePolicy, autoKey: bool = ..., **kwargs) -> None: ...
    def _ParameterTransformGroupManipulator__setPolicyValueSingle(self, policy, value, final): ...
    def _ParameterTransformGroupManipulator__transformChanged(self, transforms): ...
    def _getPolicyValue(self, policyName): ...
    def _paramValueChanged(self, args): ...
    def _setPolicyValue(self, policyName, value, final): ...
    def _timeChanged(self, args): ...
    def _updateTransformsFromPolicy(self, changedTransforms: Incomplete | None = ...): ...
    def getValuePolicy(self): ...
    def processorFinished(self): ...
    def processorStarted(self, name): ...

class PivotEventProcessor(TransformEventProcessor):
    _NAME: ClassVar[str] = ...
    def _update(self, worldStart, worldEnd, modifiers, initial: bool = ..., endChanged: bool = ..., modifiersChanged: bool = ..., final: bool = ...): ...

class RotateEventProcessor(TransformEventProcessor):
    _NAME: ClassVar[str] = ...
    _RotateEventProcessor__SNAP_INCREMENT: ClassVar[int] = ...
    _RotateEventProcessor__SNAP_KEY: ClassVar[PyQt5.QtCore.Qt.Key] = ...
    _RotateEventProcessor__SNAP_MODIFIER: ClassVar[PyQt5.QtCore.Qt.KeyboardModifier] = ...
    def __init__(self, layer, **kwargs) -> None: ...
    def _update(self, worldStart, worldEnd, modifiers, initial: bool = ..., endChanged: bool = ..., modifiersChanged: bool = ..., final: bool = ...): ...

class ScaleEventProcessor(TransformEventProcessor):
    _NAME: ClassVar[str] = ...
    def _update(self, worldStart, worldEnd, modifiers, initial: bool = ..., endChanged: bool = ..., modifiersChanged: bool = ..., final: bool = ...): ...

class ShearEventProcessor(TransformEventProcessor):
    _NAME: ClassVar[str] = ...
    _ShearEventProcessor__SHEAR_SNAP_EPS: ClassVar[float] = ...
    def _update(self, worldStart, worldEnd, modifiers, initial: bool = ..., endChanged: bool = ..., modifiersChanged: bool = ..., final: bool = ...): ...

class TransformEventProcessor(UI4.Util.Events.LayerWorldDragEventProcessor):
    _NAME: ClassVar[str] = ...
    def __init__(self, layer, lockX: bool = ..., lockY: bool = ..., **kwargs) -> None: ...
    def _getLockX(self): ...
    def _getLockY(self): ...
    def finish(self, *args, **kwargs): ...

class TransformManipulatorLayer(QT4GLLayerStack.LayerStack.Layer, UI4.Util.Events.EventProcessorHandler):
    class COMPONENTS(enum.Enum):
        PIVOT: ClassVar[COMPONENTS] = ...
        ROTATE: ClassVar[COMPONENTS] = ...
        SCALE: ClassVar[COMPONENTS] = ...
        SHEAR: ClassVar[COMPONENTS] = ...
        TRANSLATE: ClassVar[COMPONENTS] = ...
        _member_map_: ClassVar[collections.OrderedDict] = ...
        _member_names_: ClassVar[list] = ...
        _member_type_: ClassVar[type[object]] = ...
        _value2member_map_: ClassVar[dict] = ...
        @classmethod
        def __init__(cls, value) -> None: ...
        def _generate_next_value_(self, name, start, count, last_values): ...

    class COORDINATE_SYSTEM(enum.Enum):
        LOCAL: ClassVar[COORDINATE_SYSTEM] = ...
        WINDOW: ClassVar[COORDINATE_SYSTEM] = ...
        WORLD: ClassVar[COORDINATE_SYSTEM] = ...
        _member_map_: ClassVar[collections.OrderedDict] = ...
        _member_names_: ClassVar[list] = ...
        _member_type_: ClassVar[type[object]] = ...
        _value2member_map_: ClassVar[dict] = ...
        @classmethod
        def __init__(cls, value) -> None: ...
        def _generate_next_value_(self, name, start, count, last_values): ...

    class PICK(enum.Enum):
        NONE: ClassVar[PICK] = ...
        PIVOT: ClassVar[PICK] = ...
        ROTATE: ClassVar[PICK] = ...
        SCALE_X: ClassVar[PICK] = ...
        SCALE_XY: ClassVar[PICK] = ...
        SCALE_Y: ClassVar[PICK] = ...
        SHEAR_X: ClassVar[PICK] = ...
        SHEAR_Y: ClassVar[PICK] = ...
        TRANSLATE_X: ClassVar[PICK] = ...
        TRANSLATE_XY: ClassVar[PICK] = ...
        TRANSLATE_Y: ClassVar[PICK] = ...
        _member_map_: ClassVar[collections.OrderedDict] = ...
        _member_names_: ClassVar[list] = ...
        _member_type_: ClassVar[type[object]] = ...
        _value2member_map_: ClassVar[dict] = ...
        @classmethod
        def __init__(cls, value) -> None: ...
        def _generate_next_value_(self, name, start, count, last_values): ...

    class _TransformManipulatorLayer__Suppressor:
        def __init__(self, layer) -> None: ...
        def __enter__(self): ...
        def __exit__(self, excType, excValue, tb): ...
    _TransformManipulatorLayer__HANDLE_LINEWIDTH: ClassVar[float] = ...
    _TransformManipulatorLayer__HANDLE_SIZE: ClassVar[float] = ...
    _TransformManipulatorLayer__LINEWIDTH: ClassVar[float] = ...
    _TransformManipulatorLayer__PICK_AREA_SIZE: ClassVar[int] = ...
    _TransformManipulatorLayer__SELECT_BUF_SIZE: ClassVar[int] = ...
    transformChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, name: Incomplete | None = ..., visible: bool = ..., interactive: bool = ..., enabled: bool = ...) -> None: ...
    def _TransformManipulatorLayer__drawManipulator(self, p, pick: bool = ..., shadow: bool = ...): ...
    def _TransformManipulatorLayer__emitTransformChanged(self, changeInfoDict): ...
    def _TransformManipulatorLayer__getEventProcessorForPick(self, pick): ...
    def _TransformManipulatorLayer__getWorldPointOnLocalAxisAtAngle(self, rotateAngleDegrees): ...
    def _TransformManipulatorLayer__paintManipulator(self, pick: bool = ...): ...
    def _TransformManipulatorLayer__pickManipulator(self, windowMousePos, modifiers): ...
    def _clearMatrix(self): ...
    def _getComponentMatrix(self, component, toPivot, fromPivot): ...
    def _processEvent(self, event): ...
    def getMatrix(self, applyScale: bool = ..., applyShear: bool = ..., splitAroundTranslate: bool = ...): ...
    def getOrder(self): ...
    def getPivot(self): ...
    def getRotation(self): ...
    def getScale(self): ...
    def getScaleMultiplier(self): ...
    def getShear(self): ...
    def getShearAddition(self): ...
    def getSignalSuppressor(self): ...
    def getTranslation(self): ...
    def isChanged(self): ...
    def isLocked(self, component): ...
    def makeIdentity(self): ...
    def mapFromLocal(self, point, sys, applyScale: bool = ..., applyShear: bool = ...): ...
    def mapToLocal(self, point, sys, applyScale: bool = ..., applyShear: bool = ...): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def processorFinished(self): ...
    def processorStarted(self, name): ...
    def setLocked(self, component, isLocked): ...
    def setOrder(self, transformOrderTuple): ...
    def setPivot(self, pivot, emit: bool = ..., final: bool = ...): ...
    def setRotation(self, degrees, emit: bool = ..., final: bool = ...): ...
    def setScale(self, scale, emit: bool = ..., final: bool = ...): ...
    def setScaleMultiplier(self, sm): ...
    def setShear(self, shear, emit: bool = ..., final: bool = ...): ...
    def setShearAddition(self, xm): ...
    def setTranslation(self, translation: tuple, emit: bool = ..., final: bool = ...): ...
    def start(self, pick, event): ...
    def suppressSignals(self, v): ...

class TranslateEventProcessor(TransformEventProcessor):
    _NAME: ClassVar[str] = ...
    def _update(self, worldStart, worldEnd, modifiers, initial: bool = ..., endChanged: bool = ..., modifiersChanged: bool = ..., final: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import KatanaResources as KatanaResources
import KatanaResources as ResourceFiles
from . import AttrDump as AttrDump, ChildProcess as ChildProcess, ColorPaletteManager as ColorPaletteManager, Decorators as Decorators, Documentation as Documentation, EnvUtils as EnvUtils, FarmAPI as FarmAPI, FileUtils as FileUtils, Hints as Hints, IRFs as IRFs, KatanaFile as KatanaFile, LiveRenderAPI as LiveRenderAPI, NodeDebugOutput as NodeDebugOutput, NonUIPluginManager as NonUIPluginManager, OpDocumentationGenerator as OpDocumentationGenerator, ProjectSnapshot as ProjectSnapshot, RegisterToCamera as RegisterToCamera, RenderManager as RenderManager, RenderingCommon as RenderingCommon, ScenegraphBookmarkManager as ScenegraphBookmarkManager, ScenegraphUtils as ScenegraphUtils, Shelves as Shelves, StartupScripts as StartupScripts, SuperToolPlugins as SuperToolPlugins, UndoEntries as UndoEntries, UserNodes as UserNodes, WorkingSet as WorkingSet, WorkingSetClient as WorkingSetClient, WorkingSetManager as WorkingSetManager
from typing import Set, Tuple

def Initialize(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CacheManager as CacheManager
import PyFnGeolib
import PyQt5.QtWidgets
import UI4.Widgets.SceneGraphView.SceneGraphHandle
import Utils as Utils
import _weakrefset
import collections
import typing
from UI4.Widgets.SceneGraphView.Bridge import Bridge as Bridge
from UI4.Widgets.SceneGraphView.ColumnDataType import ColumnDataType as ColumnDataType
from UI4.Widgets.SceneGraphView.ColumnManager import ColumnManager as ColumnManager
from UI4.Widgets.SceneGraphView.ColumnPresetManager import ColumnPresetManager as ColumnPresetManager
from UI4.Widgets.SceneGraphView.DebugViewLink import DebugViewLink as DebugViewLink
from UI4.Widgets.SceneGraphView.Filtering.RuleManager import RuleManager as RuleManager
from UI4.Widgets.SceneGraphView.SceneGraphHandle import SceneGraphHandle as SceneGraphHandle
from UI4.Widgets.SceneGraphView.SceneGraphLocationTranslation import GetLocationName as GetLocationName, GetParentPath as GetParentPath, IsLocationUnderTopLevelLocation as IsLocationUnderTopLevelLocation
from UI4.Widgets.SceneGraphView.SceneGraphTree import SceneGraphTree as SceneGraphTree
from UI4.Widgets.SceneGraphView.SceneGraphViewClientManager import SceneGraphViewClientManager as SceneGraphViewClientManager
from UI4.Widgets.SceneGraphView.TreeWidgetViewLink import TreeWidgetViewLink as TreeWidgetViewLink
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class BridgeImpl(Bridge):
    DEFAULT_MAX_EVENTS_TO_PROCESS: ClassVar[int] = ...
    MAX_UNSORTED_LOCATIONS: ClassVar[int] = ...
    _BridgeImpl__instances: ClassVar[_weakrefset.WeakSet] = ...
    _abc_impl: ClassVar[_abc_data] = ...
    __abstractmethods__: ClassVar[frozenset] = ...
    def __init__(self, debugMode: bool, parent: PyQt5.QtWidgets.QWidget | None) -> None: ...
    def _BridgeImpl__activateLocation(self, locationPath, topLevelLocationPath: Incomplete | None = ...): ...
    def _BridgeImpl__addDummyColumn(self): ...
    def _BridgeImpl__addOrUpdateLocationCallback(self, locationEvent: PyFnGeolib.LocationEvent, topLevelLocation: str | None): ...
    def _BridgeImpl__checkAndDeliverPendingAttributeRequests(self, locationPath): ...
    def _BridgeImpl__checkAndDeliverPendingChildRequests(self, locationPath): ...
    def _BridgeImpl__columnConfigurationChanged(self): ...
    def _BridgeImpl__deleteLocationCallback(self, locationEvent: PyFnGeolib.LocationEvent, topLevelLocation): ...
    def _BridgeImpl__deleteLocationRecursive(self, locationPath, topLevelLocation, removeFromParent: bool = ...): ...
    def _BridgeImpl__deliverExistingData(self, topLevelLocationPath): ...
    def _BridgeImpl__endEventLoopCallback(self): ...
    def _BridgeImpl__evaluateFilterRules(self, handle, topLevelHandle): ...
    def _BridgeImpl__getPolishedLocationName(self, locationPath, topLevelLocationPath): ...
    def _BridgeImpl__getUpdatedTerminalOpArgs(self, oldTerminalOpArgs, newTerminalOpArgs): ...
    def _BridgeImpl__keyPressEventCallback(self, event): ...
    def _BridgeImpl__locationDataProcessedCallback(self, processedLocations): ...
    def _BridgeImpl__notifyViewLink(self, locationPath, locationCallback: typing.Callable, *args, **kwargs): ...
    def _BridgeImpl__openStateEventCallback(self, locationEvent, topLevelLocation: Incomplete | None = ...): ...
    def _BridgeImpl__recursiveDeliverData(self, treeItem, topLevelHandle, queue: collections.deque = ...): ...
    def _BridgeImpl__resetUserCallbacks(self): ...
    def _BridgeImpl__setItemDelegateTerminalOps(self, itemDelegateTerminalOpArgs): ...
    def _BridgeImpl__updateAttributeDataChildren(self, locationPath, topLevelLocationPath): ...
    def addAttributeDataItemType(self, itemTypeClass): ...
    def addColumn(self, columnName): ...
    def addColumnSet(self, columnSetName): ...
    def addRule(self, ruleName): ...
    def addTopLevelLocation(self, topLevelLocationPath: str, index: Incomplete | None = ...): ...
    def applyColumnVisibilitySettings(self, columnVisibility): ...
    def applyColumnWidthsSettings(self, columnWidths): ...
    def beginColumnConfiguration(self): ...
    def clearRuleCriteria(self, ruleName, triggerEvaluation: bool = ...): ...
    def clearTopLevelLocations(self): ...
    def collapseLocation(self, handle, topLevelHandle, recursive: bool = ...): ...
    def columnResized(self, columnIndex, newColumnWidth): ...
    def columnTitleClicked(self, columnIndex, columnTitleRect): ...
    def endColumnConfiguration(self): ...
    def expandLocation(self, handle, topLevelHandle, recursive: bool = ..., stopTypes: Incomplete | None = ...): ...
    def flushCaches(self): ...
    @classmethod
    def flushInstanceCaches(cls): ...
    def fontChanged(self): ...
    def freeze(self): ...
    def getAttributeDataItemTypes(self): ...
    def getChildLocationPathByIndex(self, parentLocationPath, childIndex): ...
    def getChildLocationPathByName(self, parentLocationPath, childName): ...
    def getColumnByIndex(self, columnIndex, visibleOnly: bool = ...): ...
    def getColumnByName(self, columnName): ...
    def getColumnDataType(self, columnIndex): ...
    def getColumnPresetManager(self): ...
    def getColumnVisibilitySettings(self): ...
    def getColumnWidthsSettings(self): ...
    def getCurrentRules(self): ...
    def getDisplayData(self, handle: SceneGraphHandle[UI4.Widgets.SceneGraphView.SceneGraphHandle.SceneGraphHandle], topLevelHandle: SceneGraphHandle[UI4.Widgets.SceneGraphView.SceneGraphHandle.SceneGraphHandle], columnIndex: int) -> None: ...
    def getNumberOfChildren(self, locationPath): ...
    def getNumberOfColumns(self, visibleOnly: bool = ...): ...
    def getNumberOfTopLevelLocations(self): ...
    def getOverrideNodeAndParameterName(self, locationPath, attributeName): ...
    def getParent(self, locationPath): ...
    def getPotentialChildren(self, locationPath): ...
    def getResolvedAttributeName(self, handle: SceneGraphHandle[UI4.Widgets.SceneGraphView.SceneGraphHandle.SceneGraphHandle], attributeName: str) -> tuple[bool, str]: ...
    def getRootColumnSet(self): ...
    def getRuleByName(self, ruleName): ...
    def getRuleMatchInversion(self): ...
    def getSceneGraphAttributes(self, locationPath, callback: Incomplete | None = ..., oneShot: bool = ...): ...
    def getSceneGraphChildren(self, parentLocationPath, callback: Incomplete | None = ..., oneShot: bool = ...): ...
    def getSceneGraphLocationPath(self, locationPath): ...
    def getTitleText(self, columnIndex): ...
    def getTopLevelDisplayIndex(self, handle): ...
    def getTopLevelLocations(self): ...
    def getViewLink(self): ...
    def hideColumnSet(self, columnSetName): ...
    def interruptClientProcessing(self): ...
    def isEditable(self, columnIndex): ...
    def isFrozen(self): ...
    def isNameColumn(self, columnIndex): ...
    def isProcessing(self): ...
    def isStopping(self): ...
    def locationNamesPolished(self): ...
    def matchRules(self, handle, topLevelHandle): ...
    def moveColumn(self, columnIndex, newColumnIndex): ...
    def removeRule(self, ruleName): ...
    def removeTopLevelLocation(self, topLevelLocationPath): ...
    def renameRule(self, oldName, newName): ...
    def resetAttributeDataItemTypes(self): ...
    def resetViewLink(self): ...
    def setKeyPressEventCallback(self, callback): ...
    def setLocationActive(self, locationPath): ...
    def setLocationAddedOrUpdatedCallback(self, callback): ...
    def setLocationCollapsedCallback(self, callback): ...
    def setLocationDataProcessedCallback(self, callback): ...
    def setLocationExpandedCallback(self, callback): ...
    def setLocationNamePolishCallback(self, callback): ...
    def setLocationNamesPolished(self, locationNamesPolished): ...
    def setLocationRemovedCallback(self, callback): ...
    def setMaxEventsToProcess(self, maxEventsToProcess): ...
    def setRuleComment(self, ruleName, comment): ...
    def setRuleCriteria(self, ruleName, criteriaName, criteria): ...
    def setRuleEnabled(self, ruleName, isEnabled): ...
    def setRuleEvaluator(self, ruleName, evaluator, useDefaultCriteria: bool = ...): ...
    def setRuleInverted(self, ruleName, isInverted): ...
    def setRuleMatchInversion(self, invert): ...
    def setRuleMatchPolicy(self, policy): ...
    def setRuleShowChildren(self, ruleName, showChildren): ...
    def setRuleTarget(self, ruleName, column): ...
    def setStopRecursiveExpandAttributeNames(self, attributeNames): ...
    def setStopRecursiveExpandLocationTypes(self, locationTypes): ...
    def setTerminalOps(self, terminalOpArgs): ...
    def setTopLevelDisplayIndex(self, locationPath, index): ...
    def setTopLevelLocations(self, topLevelLocations): ...
    def setUpdateViewportAutomatically(self, updateViewportAutomatically): ...
    def setViewNode(self, viewNode, applyImplicitResolvers: bool = ..., extraImplicitResolverOpArgs: Incomplete | None = ...): ...
    def setViewOp(self, viewOp, applyImplicitResolvers: bool = ..., extraImplicitResolverOpArgs: Incomplete | None = ...): ...
    def showColumnSet(self, columnSetName): ...
    def thaw(self): ...
    def topLevelLocationRenamed(self, oldLocationPath, newLocationPath): ...
    def updateTerminalOps(self, terminalOpArgs, txn: Incomplete | None = ...): ...
    def updateViewLink(self): ...

def _flushCachesCallback(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
from _typeshed import Incomplete
from typing import Set, Tuple

class TransientLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, name: Incomplete | None = ..., visible: bool = ..., interactive: bool = ..., enabled: bool = ...) -> None: ...
    def setLayerStack(self, stack): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyOpenColorIO as OCIO
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4Color.WidgetUtils import MiniLabelButton as MiniLabelButton, SetCompactWidgetWidth as SetCompactWidgetWidth, StripedFrame as StripedFrame
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ColorGradeWidget(PyQt5.QtWidgets.QWidget):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, addTitle: bool = ..., title: str = ..., createChildrenInScroll: bool = ...) -> None: ...
    def _ColorGradeWidget__muteClicked_CB(self): ...
    def _ColorGradeWidget__resetClicked_CB(self): ...
    def _ColorGradeWidget__valuePolicy_CB(self, valuePolicyEvent): ...
    def emitChanged(self, final): ...
    def getCC(self, policyRoot: Incomplete | None = ...): ...
    def isMuted(self): ...
    def reset(self): ...
    def setCC(self, cc, emitValueChanged: bool = ...): ...
    def setMuted(self, isMuted): ...

class MonitorGammaWidget(PyQt5.QtWidgets.QWidget):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, addTitle: bool = ..., title: str = ...) -> None: ...
    def _MonitorGammaWidget__muteClicked_CB(self): ...
    def _MonitorGammaWidget__resetClicked_CB(self): ...
    def _MonitorGammaWidget__valuePolicy_CB(self, valuePolicyEvent): ...
    def emitChanged(self, final): ...
    def getValueDict(self, policyRoot: Incomplete | None = ...): ...
    def isMuted(self): ...
    def reset(self): ...
    def setMuted(self, isMuted): ...
    def setValueDict(self, d, emitValueChanged: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class TimelineWidget(PyQt5.QtWidgets.QWidget):
    _TimelineWidget__ACTION_NONE: ClassVar[int] = ...
    _TimelineWidget__ACTION_PAN: ClassVar[int] = ...
    _TimelineWidget__ACTION_SELECT: ClassVar[int] = ...
    _TimelineWidget__ACTION_SET_TIME: ClassVar[int] = ...
    _TimelineWidget__ACTION_SLIDER_L: ClassVar[int] = ...
    _TimelineWidget__ACTION_SLIDER_PAN: ClassVar[int] = ...
    _TimelineWidget__ACTION_SLIDER_R: ClassVar[int] = ...
    _TimelineWidget__ACTION_ZOOM: ClassVar[int] = ...
    _TimelineWidget__HIT_NONE: ClassVar[int] = ...
    _TimelineWidget__HIT_SLIDER_CENTER: ClassVar[int] = ...
    _TimelineWidget__HIT_SLIDER_L: ClassVar[int] = ...
    _TimelineWidget__HIT_SLIDER_R: ClassVar[int] = ...
    _TimelineWidget__HIT_TIMELINE: ClassVar[int] = ...
    _TimelineWidget__HOVER_NONE: ClassVar[int] = ...
    _TimelineWidget__HOVER_SLIDER_CENTER: ClassVar[int] = ...
    _TimelineWidget__HOVER_SLIDER_L: ClassVar[int] = ...
    _TimelineWidget__HOVER_SLIDER_R: ClassVar[int] = ...
    currentTimeChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    fullRangeChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    keySetChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    selectionChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    timeRangeChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, *args) -> None: ...
    @staticmethod
    def CalculateTicks(rangeMin, rangeMax, posFn, invPosFn, widthFn, margin: int = ..., forceBoundLabels: bool = ...): ...
    @staticmethod
    def RoundRange(range): ...
    def _TimelineWidget__cleanRange(self, range, intify: bool = ...): ...
    def _TimelineWidget__emitCurrentTimeChanged(self, time, final): ...
    def _TimelineWidget__getSliderDivisionRects(self, sliderRect): ...
    def _TimelineWidget__getSliderExtent(self): ...
    def _TimelineWidget__getSliderTimeFromLocalPoint(self, x): ...
    def _TimelineWidget__getTickArea(self, time): ...
    def _TimelineWidget__getTickAreaExtent(self): ...
    def _TimelineWidget__getTimelineExtent(self): ...
    def _TimelineWidget__hitTestLocalPoint(self, point): ...
    def _TimelineWidget__paintArrows(self, painter): ...
    def _TimelineWidget__paintBackground(self, painter): ...
    def _TimelineWidget__paintCurrentTime(self, painter): ...
    def _TimelineWidget__paintHoverTime(self, painter): ...
    def _TimelineWidget__paintKeys(self, painter): ...
    def _TimelineWidget__paintSelection(self, painter): ...
    def _TimelineWidget__paintSlider(self, painter): ...
    def _TimelineWidget__paintTicksAndLabels(self, painter): ...
    def _TimelineWidget__setFloatTimeRange(self, floatTimeRange, update: bool = ..., final: bool = ...): ...
    def _TimelineWidget__zoomTimeRange(self, factor, center, final: bool = ...): ...
    def addKey(self, time): ...
    def allowSelection(self): ...
    def clearKeys(self): ...
    def currentTime(self): ...
    def fitTimeRangeToKeys(self): ...
    def floatHoverTime(self): ...
    def fullRange(self): ...
    def getTimeFromLocalX(self, x, floatValue: bool = ...): ...
    def hoverTime(self): ...
    def isFullRangeFinal(self): ...
    def isTimeRangeFinal(self): ...
    def keyPressEvent(self, keyEvent): ...
    def keySet(self): ...
    def leaveEvent(self, event): ...
    def mouseMoveEvent(self, mouseEvent): ...
    def mousePressEvent(self, mouseEvent): ...
    def mouseReleaseEvent(self, mouseEvent): ...
    def paintEvent(self, paintEvent): ...
    def removeKey(self, time): ...
    def resetTimeRange(self): ...
    def selectedTimeRange(self): ...
    def setAllowSelection(self, flag): ...
    def setCurrentTime(self, t): ...
    def setFullRange(self, range, final: bool = ...): ...
    def setKeys(self, keySet): ...
    def setSelectedTimeRange(self, timeRange): ...
    def setTimeRange(self, timeRange, final: bool = ...): ...
    def timeRange(self): ...
    def wheelEvent(self, wheelEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PackageSuperToolAPI.Packages
import Utils as Utils
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

__NODEDELETIONGUARD_PARAMETER_NAME: str
__g_nodeRefPrefix: str
__g_superToolGroupName: str

def AddNodeRef(destNodeOrGroupParam: NodegraphAPI.Node | NodegraphAPI.GroupParameter, key: str, node: NodegraphAPI.Node): ...
def AddPackageTypeAndPath(node: NodegraphAPI.Node, packageType: str, locationPath: str): ...
def AppendNode(nodeA: NodegraphAPI.Node, nodeB: NodegraphAPI.Node): ...
def AppendNodes(parentGroupNode: NodegraphAPI.Node, nodes: tuple[NodegraphAPI.Node, ...]): ...
def DeleteDeepParameter(parentGroupParam: NodegraphAPI.GroupParameter, paramPath: str): ...
def GetDownstreamNodes(node: NodegraphAPI.Node) -> set[NodegraphAPI.Node]: ...
def GetDownstreamPorts(port: NodegraphAPI.Port): ...
def GetEditPackageForLocationPath(mainNode: NodegraphAPI.Node, locationPath: str) -> PackageSuperToolAPI.Packages.Package | None: ...
def GetEditPackageLocationPaths(mainNode: NodegraphAPI.Node) -> list[str]: ...
def GetEditPackages(mainNode: NodegraphAPI.Node) -> list[PackageSuperToolAPI.Packages.Package]: ...
def GetPackageLocationParameterPath() -> str: ...
def GetPackageTypeParameterPath() -> str: ...
def GetRefNode(nodeOrGroupParam: NodegraphAPI.Node | NodegraphAPI.GroupParameter, key: str) -> NodegraphAPI.Node | None: ...
def GetSceneGraphPathExpression(package: PackageSuperToolAPI.Packages.Package, path: str, raiseOnMissing: bool = ...) -> str: ...
def GetSuperToolGroupName() -> str: ...
def GetUpstreamPort(port: NodegraphAPI.Port): ...
def IsNodeGuardedFromDeletion(node: NodegraphAPI.Node) -> bool: ...
def NodeDeletionGuard(node: NodegraphAPI.Node): ...
def PositionMergeInputs(mergeNode: NodegraphAPI.Node): ...
def PrependNode(nodeA: NodegraphAPI.Node, nodeB: NodegraphAPI.Node): ...
def RemoveNodeRef(nodeOrGroupParam: NodegraphAPI.Node | NodegraphAPI.GroupParameter, key: str): ...
def SetOrCreateDeepArrayParameter(parentGroupParam: NodegraphAPI.GroupParameter, paramPath: str, paramValue: list[str | int | float]) -> NodegraphAPI.GroupParameter: ...
def SetOrCreateDeepScalarParameter(parentGroupParam: NodegraphAPI.GroupParameter, paramPath: str, paramValue: str | int | float, hintString: Incomplete | None = ...) -> NodegraphAPI.GroupParameter: ...
def SetOrCreateDeepVectorParameter(parentGroupParam, paramPath, paramValue): ...
def SetPackageNodeName(package: PackageSuperToolAPI.Packages.Package): ...
def TransferNodeConnections(oldNode: NodegraphAPI.Node, newNode: NodegraphAPI.Node): ...
def UpdateChildPackagePaths(inputPackage: PackageSuperToolAPI.Packages.Package): ...
def UpdateEditPackagePaths(mainNode: NodegraphAPI.Node, previousRootLocationPath: str): ...
def WireInlineNodes(parentGroupNode: NodegraphAPI.GroupNode, nodes: list[NodegraphAPI.Node], x: int = ..., y: int = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from Callbacks.Callbacks import CallbacksManager, _TypeEnum
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

Callbacks: CallbacksManager

class CallbacksManager:
    class Type:
        exportAsset: ClassVar[_TypeEnum] = ...
        finalize3DNodeChanges: ClassVar[_TypeEnum] = ...
        onCatalogGSVPinned: ClassVar[_TypeEnum] = ...
        onGafferLightCreated: ClassVar[_TypeEnum] = ...
        onGafferMasterMaterialCreated: ClassVar[_TypeEnum] = ...
        onGafferRigCreated: ClassVar[_TypeEnum] = ...
        onGafferShaderSelected: ClassVar[_TypeEnum] = ...
        onGafferTemplateMaterialCreated: ClassVar[_TypeEnum] = ...
        onGafferThreeSceneGraphViewSetup: ClassVar[_TypeEnum] = ...
        onGafferThreeTabWidgetSetup: ClassVar[_TypeEnum] = ...
        onLiveRenderCommand: ClassVar[_TypeEnum] = ...
        onLiveRenderUpdate: ClassVar[_TypeEnum] = ...
        onLookFileMaterialActiveSet: ClassVar[_TypeEnum] = ...
        onLookFileMaterialSet: ClassVar[_TypeEnum] = ...
        onMasterMaterialAssigned: ClassVar[_TypeEnum] = ...
        onNewScene: ClassVar[_TypeEnum] = ...
        onNodeCreate: ClassVar[_TypeEnum] = ...
        onNodeDelete: ClassVar[_TypeEnum] = ...
        onRenderSetup: ClassVar[_TypeEnum] = ...
        onSceneAboutToLoad: ClassVar[_TypeEnum] = ...
        onSceneLoad: ClassVar[_TypeEnum] = ...
        onSceneSave: ClassVar[_TypeEnum] = ...
        onShutdown: ClassVar[_TypeEnum] = ...
        onStartup: ClassVar[_TypeEnum] = ...
        onStartupComplete: ClassVar[_TypeEnum] = ...
        onTabCreated: ClassVar[_TypeEnum] = ...
        onTemplateMaterialAssigned: ClassVar[_TypeEnum] = ...
        postLiveGroupPublish: ClassVar[_TypeEnum] = ...
        postLookFileBake: ClassVar[_TypeEnum] = ...
        preLiveGroupPublish: ClassVar[_TypeEnum] = ...
        preLookFileBake: ClassVar[_TypeEnum] = ...
    DeprecatedCallbackTypes: ClassVar[dict] = ...
    def __init__(self) -> None: ...
    def addCallback(self, callbackType, callbackFcn, callbackObjectHash: Incomplete | None = ...): ...
    def delCallback(self, callbackType, callbackFcn, callbackObjectHash: Incomplete | None = ...): ...
    def setCallbackTypeDeprecated(self, callbackTypeName: str, newCallbackTypeName: str): ...

class _TypeEnum:
    _TypeEnum__next: ClassVar[int] = ...
    def __init__(self, name) -> None: ...
    def get(self): ...
    def name(self): ...

class _TypeEnumList: ...

def DeclareCallbackType(callbackName): ...
def ExecuteCallbacksForType(callbackType, callbackObjectHash: Incomplete | None = ..., **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from typing import ClassVar, Set, Tuple

class CheckBoxFormWidget(BaseValueFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _CheckBoxFormWidget__checkControlWidget(self, state): ...
    def _CheckBoxFormWidget__interpretValue(self, value): ...
    def _buildControlWidget(self, layout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _lockChanged(self, state): ...
    def _updateControlWidget(self): ...

class MinimalCheckBox(PyQt5.QtWidgets.QWidget):
    stateChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self) -> None: ...
    def checkState(self) -> PyQt5.QtCore.Qt.CheckState: ...
    def mouseReleaseEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...
    def setCheckState(self, state: PyQt5.QtCore.Qt.CheckState): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import GeoAPI as GeoAPI
import typing
from PyFnGeolibProducers import GeometryProducer as GeometryProducer
from _typeshed import Incomplete
from typing import Set, Tuple

def CollectPathsFromCELStatement(producerOrClient, celStatement, interruptCallback: typing.Optional[typing.Callable] = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Panels.Edge as Edge
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class DragOverlay(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent) -> None: ...
    def _isCompositingEnabled(self): ...
    def hide(self): ...
    def paintEvent(self, event): ...
    def setPosition(self, area, rects): ...
    def show(self): ...

class HighlightRubberBand(PyQt5.QtWidgets.QRubberBand):
    def paintEvent(self, event): ...

class SplittableBoxOverlay(PyQt5.QtWidgets.QWidget):
    def __init__(self) -> None: ...
    def _SplittableBoxOverlay__tick(self): ...
    def paintEvent(self, event): ...
    def setRect(self, rect, showSplits): ...
    def show(self): ...

def GetHighlightColor(palette: PyQt5.QtGui.QPalette) -> PyQt5.QtGui.QColor: ...
def _BlendColors(c1, c2, blend): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import Utils as Utils
from typing import ClassVar, Set, Tuple

class CelResultsWidget(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent, paths) -> None: ...
    def _CelResultsWidget__aboutToDrag(self, dragItems, dragObject): ...
    def _CelResultsWidget__actionMenuAboutToShow(self): ...
    def _CelResultsWidget__deleteHidden(self): ...
    def _CelResultsWidget__deleteSelected(self): ...
    def _CelResultsWidget__filterUpdate(self, filterText): ...
    def _CelResultsWidget__keypressCallback(self, event): ...
    def _CelResultsWidget__onlyShowBaseName(self, checked): ...
    def _CelResultsWidget__selectAllVisible(self): ...
    def getTreeWidget(self): ...
    def showEvent(self, event): ...
    def sizeHint(self): ...
    def update(self): ...

class CelResultsWindow(PyQt5.QtWidgets.QDialog):
    _CelResultsWindow__dialogs: ClassVar[dict] = ...
    def __init__(self, paths) -> None: ...
    def closeEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import UI4.FormMaster.BaseParameterPolicy
import Utils as Utils
from typing import Set, Tuple

class ParameterPolicyDelegate:
    def createPolicy(self, parentPolicy, param): ...

def CreateDefaultParameterPolicy(parentPolicy, param): ...
def CreateParameterPolicy(parentPolicy: UI4.FormMaster.BaseParameterPolicy.BaseParameterPolicy | None, param: NodegraphAPI.Parameter) -> UI4.FormMaster.BaseParameterPolicy.BaseParameterPolicy | None: ...
def IsParameterEnabled(param): ...
def RegisterPolicyDelegate(typeName, delegate): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import UI4.NodeMaster.NodeInteractionDelegateManager
from typing import Set, Tuple

class MaterialStackDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    def addToNodeSpecificShelfEnvironment(self, targetNode, editor, envDict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import GeoAPI as GeoAPI
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
import PyFnGeolibProducers
import RenderingAPI as RenderingAPI
import PyResolutionTableFn as ResolutionTable
import Utils as Utils
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

class RenderCameraError(RenderingAPI.RenderStartupError): ...

class RenderNodeInfo:
    def __init__(self, node: NodegraphAPI.Node, graphState: NodegraphAPI.GraphState, producer: PyFnGeolibProducers.GeometryProducer, cacheID, cameraErrorIsFatal: bool = ...) -> None: ...
    def _RenderNodeInfo__computeTargetFileName(self, outputAttrs, forceLocal, makeVersionTemplate, imageInfoDict): ...
    def _RenderNodeInfo__computeTargetLocation(self, outputAttrs, forceLocal, imageInfoDict): ...
    def _RenderNodeInfo__compute_tile_file_name(self, outputType, outputFile, tileRender: Incomplete | None = ..., shadowType: str = ...): ...
    def _RenderNodeInfo__getOutputAttr(self, outputAttrs, attrName, defValue): ...
    def _RenderNodeInfo__getProducerData(self, cameraErrorIsFatal: bool = ...): ...
    def _RenderNodeInfo__getRenderSettingsAttributesDict(self, excludeOutputs: bool = ...) -> dict: ...
    def _RenderNodeInfo__process_color_output(self, name, outputAttrs, outputScope, forceLocal, enabled, makeVersionTemplate, imageInfoDict): ...
    def _RenderNodeInfo__process_deep_output(self, name, outputAttrs, outputScope, forceLocal, enabled, makeVersionTemplate, imageInfoDict): ...
    def _RenderNodeInfo__process_other_output(self, name, outputAttrs, outputScope, forceLocal, enabled, makeVersionTemplate, imageInfoDict): ...
    def _RenderNodeInfo__process_output(self, index, forceLocal, makeVersionTemplate): ...
    def _RenderNodeInfo__process_prescript_output(self, name, outputAttrs, outputScope, forceLocal, enabled, makeVersionTemplate, imageInfoDict): ...
    def _RenderNodeInfo__process_raw_output(self, name, outputAttrs, outputScope, forceLocal, enabled, makeVersionTemplate, imageInfoDict): ...
    def _RenderNodeInfo__process_script_output(self, name, outputAttrs, outputScope, forceLocal, enabled, makeVersionTemplate, imageInfoDict): ...
    def _RenderNodeInfo__process_shadow_output(self, name, outputAttrs, outputScope, forceLocal, enabled, makeVersionTemplate, imageInfoDict): ...
    def _RenderNodeInfo__resolvePathsInCommand(self, command): ...
    def computeTileFileName(self, outputInfo, tileRender: Incomplete | None = ...): ...
    def getAllOutputNames(self): ...
    def getCacheID(self): ...
    def getExplicitOutputVersion(self): ...
    def getIncludedByDefault(self, name): ...
    def getNumberOfOutputs(self): ...
    def getOutputInfoByIndex(self, index, forceLocal, makeVersionTemplate: bool = ...): ...
    def getOutputInfoByName(self, name, forceLocal, makeVersionTemplate: bool = ...): ...
    def getPackageString(self): ...
    def getProducer(self): ...
    def getRenderSettings(self): ...
    def getRendererString(self): ...
    def getTileStitchWork(self, tileInfo, tileCleanup, forceLocal): ...
    def isTileRender(self): ...
    def shouldForceLegacyChannelNames(self, outputPassName: str) -> bool: ...

class RenderSettingsError(RenderingAPI.RenderStartupError): ...

def ClearRenderNodeInfoCache(node: NodegraphAPI.Node, graphState: NodegraphAPI.GraphState): ...
def CreateOutputOverrideOp(txn, inputOp, node: NodegraphAPI.Node, graphState: NodegraphAPI.GraphState): ...
def GetCameraInfoDict(cameraProducer): ...
def GetDefaultIncludedOutputs(node: NodegraphAPI.Node): ...
def GetNumRenderOutputs(node: NodegraphAPI.Node, producer: typing.Optional[PyFnGeolibProducers.GeometryProducer] = ...): ...
def GetOutputIncluded(node: NodegraphAPI.Node, outputName): ...
def GetRenderNodeInfo(node: NodegraphAPI.Node, graphState: typing.Optional[NodegraphAPI.GraphState] = ..., client: Incomplete | None = ..., cameraErrorIsFatal: bool = ...) -> RenderNodeInfo: ...
def GetRenderOutputLocation(node: NodegraphAPI.Node, idx, producer: typing.Optional[PyFnGeolibProducers.GeometryProducer] = ..., graphState: typing.Optional[NodegraphAPI.GraphState] = ..., withActiveFrameRange: bool = ...): ...
def GetRenderOutputType(node: NodegraphAPI.Node, idx, producer: typing.Optional[PyFnGeolibProducers.GeometryProducer] = ...): ...
def GetRenderSettings(globalsProducer: PyFnGeolibProducers.GeometryProducer | None, sampleRate: tuple = ..., ROI: Incomplete | None = ..., cameraErrorIsFatal: bool = ...) -> dict: ...
def PostCreateAllProductsAndLocations(node: NodegraphAPI.Node, versionup): ...
def PostCreateProductAndLocation(node: NodegraphAPI.Node, idx, versionup, assetTxn: Incomplete | None = ...): ...
def PreCreateAllProductsAndLocations(node: NodegraphAPI.Node, versionup, producer: typing.Optional[PyFnGeolibProducers.GeometryProducer] = ...): ...
def PreCreateProductAndLocation(node: NodegraphAPI.Node, idx, versionup, assetTxn: Incomplete | None = ...): ...
def SetOutputIncluded(node: NodegraphAPI.Node, outputName, included): ...
def SyncAllOutputPorts(): ...
def SyncOutputPorts(node: NodegraphAPI.Node, cameraErrorIsFatal: bool = ...): ...
def UpdateIncludedOutputs(node: NodegraphAPI.Node, updateDict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.FWidget as FWidget
import QT4FormWidgets.FWidget
import PyQt5.QtCore as QtCore
import ResourceFiles as ResourceFiles
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import Set, Tuple

class FormClose(QT4FormWidgets.FWidget.FPixmap):
    def __init__(self, parent) -> None: ...
    def _FormClose__on_fpixmap_clicked(self): ...
    def paint(self, painter, width, height): ...
    def setEnabled(self, yorn): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class ComboBoxNoWheel(PyQt5.QtWidgets.QComboBox):
    clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def keyPressEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def wheelEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.Version.Registry as Registry
import NodegraphAPI.Xio as Xio
from typing import Set, Tuple

class Updater:
    def __init__(self) -> None: ...
    def update(self, document): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyQt5.QtCore as QtCore
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import typing
from UI4.Widgets.ModalProcessInterruptWidget import ModalProcessInterruptWidget as ModalProcessInterruptWidget
from _typeshed import Incomplete
from typing import Set, Tuple

class CollectAndSelectInScenegraph:
    def __init__(self, cel, loc) -> None: ...
    def _CollectAndSelectInScenegraph__collectionInterruptCallback(self, numFound, t): ...
    def _CollectAndSelectInScenegraph__setInterrupt(self): ...
    def collectAndSelect(self, select: bool = ..., replace: bool = ..., node: typing.Optional[NodegraphAPI.Node] = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import PyXmlIO as PyXmlIO
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def AddLinearGradLayer(layerParam, name: Incomplete | None = ...): ...
def AddSuperGradLayer(node: NodegraphAPI.Node, x: float = ..., y: float = ..., r: float = ..., g: float = ..., b: float = ..., a: float = ...): ...
def SetGradLayerName(layerParam, name): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFCurve as PyFCurve
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import ConfigurationAPI_cmodule as Configuration
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import LookFileBakeAPI as LookFileBakeAPI
import LookFileBakeAPI.LookFileUtil as LookFileUtil
import NodegraphAPI as NodegraphAPI
import typing
from LookFileBakeAPI.Constants import OutputFormat as OutputFormat
from LookFileBakeAPI.Exceptions import LookFileBakeException as LookFileBakeException
from Nodes3DAPI.Node3D import Node3D as Node3D
from _typeshed import Incomplete
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class LookFileMaterialsOut(Node3D):
    def __init__(self) -> None: ...
    def WriteLookFileToDirectory(self, outputFormatName: str, graphState: Tuple[NodegraphAPI.GraphState, float | None], outputPath: str, progressCallback: typing.Optional[typing.Callable] = ...) -> list[str]: ...
    def WriteToAsset(self, graphState: NodegraphAPI.GraphState, assetId, args: Incomplete | None = ..., progressCallback: typing.Optional[typing.Callable] = ...): ...
    def WriteToCompoundFile(self, graphState: Tuple[NodegraphAPI.GraphState, float | None], filePath: str, progressCallback: typing.Optional[typing.Callable] = ...): ...
    def WriteToDirectory(self, graphState: Tuple[NodegraphAPI.GraphState, float | None], dirPath: str, progressCallback: typing.Optional[typing.Callable] = ...) -> list[str]: ...
    def WriteToLookFile(self, graphState: Tuple[NodegraphAPI.GraphState, float | None], outputPath: str, *args, **kw) -> list[str]: ...
    def _LookFileMaterialsOut__getProducer(self, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
    def test(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.SceneGraphView.TreeWidgetItems
from UI4.Widgets.SceneGraphView.TreeWidgetItems import LocationTreeWidgetItem as LocationTreeWidgetItem
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class SceneGraphHandle:
    _SceneGraphHandle__defaultItemTypeClass: ClassVar[type[UI4.Widgets.SceneGraphView.TreeWidgetItems.LocationTreeWidgetItem]] = ...
    def __init__(self, locationPath: str | None, isTopLevelLocation: bool, itemTypeClass: Incomplete | None = ..., attribute: Incomplete | None = ...) -> None: ...
    def getAttribute(self) -> PyFnAttribute | None: ...
    def getItemTypeClass(self) -> type: ...
    def getLocationPath(self) -> str | None: ...
    def isLocationType(self) -> bool: ...
    def isTopLevelLocation(self) -> bool: ...
